@@ -1,5 +1,5 @@
 /*
- * $Id: optimizer.c 39824 2009-06-29 07:11:48Z petdance $
+ * $Id$
  * Copyright (C) 2002-2009, Parrot Foundation.
  */
 
@@ -73,6 +73,7 @@ e.g. eliminate new Px .PerlUndef because Px where different before
 #include "imc.h"
 #include "pbc.h"
 #include "optimizer.h"
+#include "pmc/pmc_callcontext.h"
 
 /* HEADERIZER HFILE: compilers/imcc/optimizer.h */
 
@@ -151,43 +152,43 @@ static int used_once(PARROT_INTERP, ARGMOD(IMC_Unit *unit))
         __attribute__nonnull__(2)
         FUNC_MODIFIES(*unit);
 
-#define ASSERT_ARGS_branch_branch __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+#define ASSERT_ARGS_branch_branch __attribute__unused__ int _ASSERT_ARGS_CHECK = (\
        PARROT_ASSERT_ARG(interp) \
-    || PARROT_ASSERT_ARG(unit)
-#define ASSERT_ARGS_branch_cond_loop __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+    , PARROT_ASSERT_ARG(unit))
+#define ASSERT_ARGS_branch_cond_loop __attribute__unused__ int _ASSERT_ARGS_CHECK = (\
        PARROT_ASSERT_ARG(interp) \
-    || PARROT_ASSERT_ARG(unit)
-#define ASSERT_ARGS_branch_cond_loop_swap __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+    , PARROT_ASSERT_ARG(unit))
+#define ASSERT_ARGS_branch_cond_loop_swap __attribute__unused__ int _ASSERT_ARGS_CHECK = (\
        PARROT_ASSERT_ARG(interp) \
-    || PARROT_ASSERT_ARG(unit) \
-    || PARROT_ASSERT_ARG(branch) \
-    || PARROT_ASSERT_ARG(start) \
-    || PARROT_ASSERT_ARG(cond)
-#define ASSERT_ARGS_branch_reorg __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+    , PARROT_ASSERT_ARG(unit) \
+    , PARROT_ASSERT_ARG(branch) \
+    , PARROT_ASSERT_ARG(start) \
+    , PARROT_ASSERT_ARG(cond))
+#define ASSERT_ARGS_branch_reorg __attribute__unused__ int _ASSERT_ARGS_CHECK = (\
        PARROT_ASSERT_ARG(interp) \
-    || PARROT_ASSERT_ARG(unit)
-#define ASSERT_ARGS_constant_propagation __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+    , PARROT_ASSERT_ARG(unit))
+#define ASSERT_ARGS_constant_propagation __attribute__unused__ int _ASSERT_ARGS_CHECK = (\
        PARROT_ASSERT_ARG(interp) \
-    || PARROT_ASSERT_ARG(unit)
-#define ASSERT_ARGS_dead_code_remove __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+    , PARROT_ASSERT_ARG(unit))
+#define ASSERT_ARGS_dead_code_remove __attribute__unused__ int _ASSERT_ARGS_CHECK = (\
        PARROT_ASSERT_ARG(interp) \
-    || PARROT_ASSERT_ARG(unit)
-#define ASSERT_ARGS_eval_ins __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+    , PARROT_ASSERT_ARG(unit))
+#define ASSERT_ARGS_eval_ins __attribute__unused__ int _ASSERT_ARGS_CHECK = (\
        PARROT_ASSERT_ARG(interp) \
-    || PARROT_ASSERT_ARG(op) \
-    || PARROT_ASSERT_ARG(r)
-#define ASSERT_ARGS_if_branch __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+    , PARROT_ASSERT_ARG(op) \
+    , PARROT_ASSERT_ARG(r))
+#define ASSERT_ARGS_if_branch __attribute__unused__ int _ASSERT_ARGS_CHECK = (\
        PARROT_ASSERT_ARG(interp) \
-    || PARROT_ASSERT_ARG(unit)
-#define ASSERT_ARGS_strength_reduce __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+    , PARROT_ASSERT_ARG(unit))
+#define ASSERT_ARGS_strength_reduce __attribute__unused__ int _ASSERT_ARGS_CHECK = (\
        PARROT_ASSERT_ARG(interp) \
-    || PARROT_ASSERT_ARG(unit)
-#define ASSERT_ARGS_unused_label __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+    , PARROT_ASSERT_ARG(unit))
+#define ASSERT_ARGS_unused_label __attribute__unused__ int _ASSERT_ARGS_CHECK = (\
        PARROT_ASSERT_ARG(interp) \
-    || PARROT_ASSERT_ARG(unit)
-#define ASSERT_ARGS_used_once __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+    , PARROT_ASSERT_ARG(unit))
+#define ASSERT_ARGS_used_once __attribute__unused__ int _ASSERT_ARGS_CHECK = (\
        PARROT_ASSERT_ARG(interp) \
-    || PARROT_ASSERT_ARG(unit)
+    , PARROT_ASSERT_ARG(unit))
 /* Don't modify between HEADERIZER BEGIN / HEADERIZER END.  Your changes will be lost. */
 /* HEADERIZER END: static */
 
@@ -209,7 +210,6 @@ pre_optimize(PARROT_INTERP, ARGMOD(IMC_Unit *unit))
 
     if (IMCC_INFO(interp)->optimizer_level & OPT_PRE) {
         IMCC_info(interp, 2, "pre_optimize\n");
-        /* RT #46281 integrate all in one pass */
         changed += strength_reduce(interp, unit);
         if (!IMCC_INFO(interp)->dont_optimize)
             changed += if_branch(interp, unit);
@@ -244,7 +244,6 @@ cfg_optimize(PARROT_INTERP, ARGMOD(IMC_Unit *unit))
             return 1;
         if (branch_reorg(interp, unit))
             return 1;
-        /* RT #46283 cfg / loop detection breaks e.g. in t/compiler/5_3 */
         if (unused_label(interp, unit))
             return 1;
         if (dead_code_remove(interp, unit))
@@ -695,7 +694,7 @@ constant_propagation(PARROT_INTERP, ARGMOD(IMC_Unit *unit))
                                     ins2, i);
                             old = ins2->symregs[i];
                             ins2->symregs[i] = c;
-       /* first we try subst_constants for e.g. if 10 < 5 goto next*/
+                /* first we try subst_constants for e.g. if 10 < 5 goto next*/
                             tmp = IMCC_subst_constants(interp,
                                 unit, ins2->opname, ins2->symregs, ins2->opsize,
                                 &found);
@@ -811,38 +810,38 @@ eval_ins(PARROT_INTERP, ARGIN(const char *op), size_t ops, ARGIN(SymReg **r))
     eval[0] = opnum;
     for (i = 0; i < op_info->op_count - 1; i++) {
         switch (op_info->types[i]) {
-            case PARROT_ARG_IC:
-                PARROT_ASSERT(i && ops == (unsigned int)i);
-                /* set branch offset to zero */
-                eval[i + 1] = 0;
-                break;
-            case PARROT_ARG_I:
-            case PARROT_ARG_N:
-            case PARROT_ARG_S:
-                eval[i + 1] = i;        /* regs used are I0, I1, I2 */
-                if (ops <= 2 || i) { /* fill source regs */
-                    switch (r[i]->set) {
-                        case 'I':
-                            REG_INT(interp, i) = IMCC_int_from_reg(interp, r[i]);
-                            break;
-                        case 'N':
-                            {
-                            STRING * const s = Parrot_str_new(interp, r[i]->name, 0);
-                            REG_NUM(interp, i) = Parrot_str_to_num(interp, s);
-                            }
-                            break;
-                        case 'S':
-                            REG_STR(interp, i) = IMCC_string_from_reg(interp, r[i]);
-                            break;
-                        default:
-                            break;
+          case PARROT_ARG_IC:
+            PARROT_ASSERT(i && ops == (unsigned int)i);
+            /* set branch offset to zero */
+            eval[i + 1] = 0;
+            break;
+          case PARROT_ARG_I:
+          case PARROT_ARG_N:
+          case PARROT_ARG_S:
+            eval[i + 1] = i;        /* regs used are I0, I1, I2 */
+            if (ops <= 2 || i) { /* fill source regs */
+                switch (r[i]->set) {
+                  case 'I':
+                    REG_INT(interp, i) = IMCC_int_from_reg(interp, r[i]);
+                    break;
+                  case 'N':
+                    {
+                        STRING * const s = Parrot_str_new(interp, r[i]->name, 0);
+                        REG_NUM(interp, i) = Parrot_str_to_num(interp, s);
                     }
+                    break;
+                  case 'S':
+                    REG_STR(interp, i) = IMCC_string_from_reg(interp, r[i]);
+                    break;
+                  default:
+                    break;
                 }
-                break;
-            default:
-                IMCC_fatal(interp, 1, "eval_ins"
-                        "invalid arg #%d for op '%s' not found\n",
-                        i, op);
+            }
+            break;
+          default:
+            IMCC_fatal(interp, 1, "eval_ins"
+                    "invalid arg #%d for op '%s' not found\n",
+                    i, op);
         }
     }
 
@@ -1011,7 +1010,8 @@ IMCC_subst_constants(PARROT_INTERP, ARGMOD(IMC_Unit *unit), ARGIN(const char *na
      */
     branched = eval_ins(interp, op, found, r);
     if (branched == -1) {
-         /* Don't set ok (See RT #43048 for info) */
+         /* Don't set ok
+          * (See http://rt.perl.org/rt3/Ticket/Display.html?id=43048 for info) */
          return NULL;
     }
     /*
@@ -1037,27 +1037,27 @@ IMCC_subst_constants(PARROT_INTERP, ARGMOD(IMC_Unit *unit), ARGIN(const char *na
          */
         char b[128];
         switch (r[0]->set) {
-            case 'I':
-                snprintf(b, sizeof (b), INTVAL_FMT, REG_INT(interp, 0));
-                r[1] = mk_const(interp, b, r[0]->set);
-                break;
-            case 'N':
-                snprintf(b, sizeof (b), fmt, REG_NUM(interp, 0));
-                r[1] = mk_const(interp, b, r[0]->set);
-                break;
-            case 'S':
-            {
-                char * const name = Parrot_str_to_cstring(interp, REG_STR(interp, 0));
+          case 'I':
+            snprintf(b, sizeof (b), INTVAL_FMT, REG_INT(interp, 0));
+            r[1] = mk_const(interp, b, r[0]->set);
+            break;
+          case 'N':
+            snprintf(b, sizeof (b), fmt, REG_NUM(interp, 0));
+            r[1] = mk_const(interp, b, r[0]->set);
+            break;
+          case 'S':
+          {
+            char * const name = Parrot_str_to_cstring(interp, REG_STR(interp, 0));
 
-                r[1] = mk_const(interp, name, r[0]->set);
+            r[1] = mk_const(interp, name, r[0]->set);
 
-                snprintf(b, sizeof (b), "%p", REG_STR(interp, 0));
-                Parrot_str_free_cstring(name);
+            snprintf(b, sizeof (b), "%p", REG_STR(interp, 0));
+            Parrot_str_free_cstring(name);
 
-                break;
-            }
-            default:
-                break;
+            break;
+          }
+          default:
+            break;
         }
         tmp = INS(interp, unit, "set", "", r, 2, 0, 0);
     }
@@ -1501,14 +1501,12 @@ dead_code_remove(PARROT_INTERP, ARGMOD(IMC_Unit *unit))
         }
     }
 
-    /* Unreachable instructions */
 
+    /* Unreachable instructions */
 
     for (last = unit->instructions, ins = last->next;
          last && ins;
          ins = ins->next) {
-         if (!last && !ins)
-            break;
 
         if ((last->type & IF_goto) && !(ins->type & ITLABEL) &&
             STREQ(last->opname, "branch")) {
