@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2002-2009, Parrot Foundation.
- * $Id: symreg.c 39843 2009-06-30 14:45:25Z petdance $
+ * $Id$
  */
 
 /*
@@ -29,10 +29,6 @@ and SymbolTable (see symbol.h and symbol.c)
 
 #include "imc.h"
 
-/* Globals: */
-
-static Namespace * pesky_global__namespace;
-
 /* Code: */
 
 /* HEADERIZER HFILE: compilers/imcc/symreg.h */
@@ -103,29 +99,29 @@ static void resize_symhash(ARGMOD(SymHash *hsh))
         __attribute__nonnull__(1)
         FUNC_MODIFIES(*hsh);
 
-#define ASSERT_ARGS__get_sym_typed __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+#define ASSERT_ARGS__get_sym_typed __attribute__unused__ int _ASSERT_ARGS_CHECK = (\
        PARROT_ASSERT_ARG(hsh) \
-    || PARROT_ASSERT_ARG(name)
-#define ASSERT_ARGS__mk_fullname __attribute__unused__ int _ASSERT_ARGS_CHECK = \
-       PARROT_ASSERT_ARG(name)
-#define ASSERT_ARGS__mk_symreg __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+    , PARROT_ASSERT_ARG(name))
+#define ASSERT_ARGS__mk_fullname __attribute__unused__ int _ASSERT_ARGS_CHECK = (\
+       PARROT_ASSERT_ARG(name))
+#define ASSERT_ARGS__mk_symreg __attribute__unused__ int _ASSERT_ARGS_CHECK = (\
        PARROT_ASSERT_ARG(hsh) \
-    || PARROT_ASSERT_ARG(name)
-#define ASSERT_ARGS_add_ns __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+    , PARROT_ASSERT_ARG(name))
+#define ASSERT_ARGS_add_ns __attribute__unused__ int _ASSERT_ARGS_CHECK = (\
        PARROT_ASSERT_ARG(interp) \
-    || PARROT_ASSERT_ARG(name)
-#define ASSERT_ARGS_get_sym_by_name __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+    , PARROT_ASSERT_ARG(name))
+#define ASSERT_ARGS_get_sym_by_name __attribute__unused__ int _ASSERT_ARGS_CHECK = (\
        PARROT_ASSERT_ARG(hsh) \
-    || PARROT_ASSERT_ARG(name)
-#define ASSERT_ARGS_int_overflows __attribute__unused__ int _ASSERT_ARGS_CHECK = \
-       PARROT_ASSERT_ARG(r)
-#define ASSERT_ARGS_mk_pmc_const_2 __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+    , PARROT_ASSERT_ARG(name))
+#define ASSERT_ARGS_int_overflows __attribute__unused__ int _ASSERT_ARGS_CHECK = (\
+       PARROT_ASSERT_ARG(r))
+#define ASSERT_ARGS_mk_pmc_const_2 __attribute__unused__ int _ASSERT_ARGS_CHECK = (\
        PARROT_ASSERT_ARG(interp) \
-    || PARROT_ASSERT_ARG(unit) \
-    || PARROT_ASSERT_ARG(left) \
-    || PARROT_ASSERT_ARG(rhs)
-#define ASSERT_ARGS_resize_symhash __attribute__unused__ int _ASSERT_ARGS_CHECK = \
-       PARROT_ASSERT_ARG(hsh)
+    , PARROT_ASSERT_ARG(unit) \
+    , PARROT_ASSERT_ARG(left) \
+    , PARROT_ASSERT_ARG(rhs))
+#define ASSERT_ARGS_resize_symhash __attribute__unused__ int _ASSERT_ARGS_CHECK = (\
+       PARROT_ASSERT_ARG(hsh))
 /* Don't modify between HEADERIZER BEGIN / HEADERIZER END.  Your changes will be lost. */
 /* HEADERIZER END: static */
 
@@ -140,14 +136,14 @@ Begins a new namespace in PASM/PIR, named after the given C<name>.
 */
 
 void
-push_namespace(SHIM_INTERP, ARGIN(const char *name))
+push_namespace(PARROT_INTERP, ARGIN(const char *name))
 {
     ASSERT_ARGS(push_namespace)
     Namespace * const ns = mem_allocate_zeroed_typed(Namespace);
 
-    ns->parent = pesky_global__namespace;
+    ns->parent = IMCC_INFO(interp)->namespace_stack;
     ns->name   = mem_sys_strdup(name);
-    pesky_global__namespace = ns;
+    IMCC_INFO(interp)->namespace_stack = ns;
 }
 
 
@@ -166,7 +162,7 @@ void
 pop_namespace(PARROT_INTERP, ARGIN(const char *name))
 {
     ASSERT_ARGS(pop_namespace)
-    Namespace * const ns = pesky_global__namespace;
+    Namespace * const ns = IMCC_INFO(interp)->namespace_stack;
 
     if (!ns)
         IMCC_fataly(interp, EXCEPTION_SYNTAX_ERROR, "pop() on empty namespace stack\n");
@@ -181,7 +177,7 @@ pop_namespace(PARROT_INTERP, ARGIN(const char *name))
         mem_sys_free(ident);
     }
 
-    pesky_global__namespace = ns->parent;
+    IMCC_INFO(interp)->namespace_stack = ns->parent;
     mem_sys_free(ns);
 }
 
@@ -340,6 +336,7 @@ symreg_to_str(ARGIN(const SymReg *s))
     if (t & VT_FLAT)      { strcat(buf, "VT_FLAT ");       }
     if (t & VT_OPTIONAL)  { strcat(buf, "VT_OPTIONAL ");   }
     if (t & VT_NAMED)     { strcat(buf, "VT_NAMED ");      }
+    if (t & VT_CALL_SIG)  { strcat(buf, "VT_CALL_SIG ");   }
 
     strcat(buf, "]");
 
@@ -465,7 +462,7 @@ add_pcc_arg(ARGMOD(SymReg *r), ARGMOD(SymReg *arg))
     sub->args[n]      = arg;
     sub->arg_flags[n] = arg->type;
 
-    arg->type &= ~(VT_FLAT|VT_OPTIONAL|VT_OPT_FLAG|VT_NAMED);
+    arg->type &= ~(VT_FLAT|VT_OPTIONAL|VT_OPT_FLAG|VT_NAMED|VT_CALL_SIG);
 
     sub->nargs++;
 }
@@ -640,23 +637,22 @@ SymReg *
 mk_ident(PARROT_INTERP, ARGIN(const char *name), int t)
 {
     ASSERT_ARGS(mk_ident)
-    char   * const fullname = _mk_fullname(pesky_global__namespace, name);
+    char   * const fullname = _mk_fullname(IMCC_INFO(interp)->namespace_stack, name);
     SymReg *r = get_sym_by_name(&(IMCC_INFO(interp)->last_unit->hash), name);
-    if (r && r->set != t) {
-        IMCC_print_inc(interp);
-        IMCC_warning(interp, "Duplicated IDENTIFIER '%s'\n", fullname);
-    }
+    if (r && r->set != t)
+        IMCC_fataly(interp, EXCEPTION_SYNTAX_ERROR,
+                "syntax error, duplicated IDENTIFIER '%s'\n", fullname);
 
     r = mk_symreg(interp, fullname, t);
     r->type = VTIDENTIFIER;
 
 
-    if (pesky_global__namespace) {
+    if (IMCC_INFO(interp)->namespace_stack) {
         Identifier * const ident = mem_allocate_zeroed_typed(Identifier);
 
         ident->name        = fullname;
-        ident->next        = pesky_global__namespace->idents;
-        pesky_global__namespace->idents = ident;
+        ident->next        = IMCC_INFO(interp)->namespace_stack->idents;
+        IMCC_INFO(interp)->namespace_stack->idents = ident;
     }
     else
         mem_sys_free(fullname);
@@ -734,14 +730,14 @@ mk_pmc_const_2(PARROT_INTERP, ARGMOD(IMC_Unit *unit), ARGIN(SymReg *left),
     rhs->pmc_type = left->pmc_type;
 
     switch (rhs->pmc_type) {
-        case enum_class_Sub:
-        case enum_class_Coroutine:
-            r[1]       = rhs;
-            rhs->usage = U_FIXUP;
-            INS(interp, unit, "set_p_pc", "", r, 2, 0, 1);
-            return NULL;
-        default:
-            break;
+      case enum_class_Sub:
+      case enum_class_Coroutine:
+        r[1]        = rhs;
+        rhs->usage |= U_FIXUP;
+        INS(interp, unit, "set_p_pc", "", r, 2, 0, 1);
+        return NULL;
+      default:
+        break;
     }
 
     r[1] = rhs;
@@ -829,7 +825,9 @@ _mk_const(ARGMOD(SymHash *hsh), ARGIN(const char *name), int t)
         r->type |= VT_ENCODED;
     }
 
-    /* autopromote big ints to floats; fallout from RT #53908 */
+    /* autopromote big ints to floats; fallout from
+     * http://rt.perl.org/rt3/Ticket/Display.html?id=53908
+     * */
     if (t == 'I') {
         if (int_overflows(r))
             r->set = 'N';
@@ -977,10 +975,19 @@ _mk_address(PARROT_INTERP, ARGMOD(SymHash *hsh), ARGIN(const char *name), int un
     SymReg *r;
 
     if (uniq == U_add_all) {
+        int is_lexical = 0;
+        r = get_sym_by_name(&IMCC_INFO(interp)->ghash, name);
+
+        if (r && r->usage & U_LEXICAL)
+            is_lexical = 1;
+
         r       = mem_allocate_zeroed_typed(SymReg);
         r->type = VTADDRESS;
         r->name = mem_sys_strdup(name);
         _store_symreg(hsh, r);
+
+        if (is_lexical)
+            r->usage |= U_LEXICAL;
     }
     else {
         /* Aux var to avoid the need of const casts */
@@ -1191,7 +1198,6 @@ link_keys(PARROT_INTERP, int nargs, ARGMOD(SymReg **keys), int force)
     SymReg *key;
     SymReg *keychain;
     int     i;
-    int     any_slice = 0;
     size_t  len       = 0;
 
     /* namespace keys are global consts - no cur_unit */
@@ -1203,7 +1209,7 @@ link_keys(PARROT_INTERP, int nargs, ARGMOD(SymReg **keys), int force)
         IMCC_fataly(interp, EXCEPTION_SYNTAX_ERROR, "link_keys: huh? no keys\n");
 
     /* short-circuit simple key unless we've been told not to */
-    if (nargs == 1 && !force && !(keys[0]->type & VT_SLICE_BITS))
+    if (nargs == 1 && !force)
         return keys[0];
 
     /* calc len of key_str
@@ -1211,13 +1217,8 @@ link_keys(PARROT_INTERP, int nargs, ARGMOD(SymReg **keys), int force)
      * have the slice flag set */
     for (i = 0; i < nargs; i++) {
         len += 1 + strlen(keys[i]->name);
-        if (keys[i]->type & VT_SLICE_BITS)
-            any_slice = 1;
     }
 
-    if (any_slice && !(keys[0]->type & VT_SLICE_BITS))
-        keys[0]->type |= (VT_START_SLICE|VT_END_SLICE);
-
     key_str  = (char *)mem_sys_allocate(len);
     *key_str = '\0';
 
@@ -1229,7 +1230,7 @@ link_keys(PARROT_INTERP, int nargs, ARGMOD(SymReg **keys), int force)
             strcat(key_str, ";");
     }
 
-    if (!any_slice && ((keychain = _get_sym(h, key_str)) != NULL)) {
+    if ((keychain = _get_sym(h, key_str)) != NULL) {
         mem_sys_free(key_str);
         return keychain;
     }
@@ -1552,7 +1553,7 @@ find_sym(PARROT_INTERP, ARGIN(const char *name))
 {
     ASSERT_ARGS(find_sym)
     if (IMCC_INFO(interp)->cur_unit)
-        return _find_sym(interp, pesky_global__namespace,
+        return _find_sym(interp, IMCC_INFO(interp)->namespace_stack,
             &IMCC_INFO(interp)->cur_unit->hash, name);
 
     return NULL;
