@@ -1,5 +1,5 @@
 /*
- * $Id: pirerr.h 38479 2009-05-05 04:15:26Z petdance $
+ * $Id$
  * Copyright (C) 2008-2009, Parrot Foundation.
  */
 
@@ -28,12 +28,12 @@ yypirerror(
         __attribute__nonnull__(2)
         __attribute__nonnull__(3);
 
-#define ASSERT_ARGS_panic __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+#define ASSERT_ARGS_panic __attribute__unused__ int _ASSERT_ARGS_CHECK = (\
        PARROT_ASSERT_ARG(lexer) \
-    || PARROT_ASSERT_ARG(message)
-#define ASSERT_ARGS_yypirerror __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+    , PARROT_ASSERT_ARG(message))
+#define ASSERT_ARGS_yypirerror __attribute__unused__ int _ASSERT_ARGS_CHECK = (\
        PARROT_ASSERT_ARG(lexer) \
-    || PARROT_ASSERT_ARG(message)
+    , PARROT_ASSERT_ARG(message))
 /* Don't modify between HEADERIZER BEGIN / HEADERIZER END.  Your changes will be lost. */
 /* HEADERIZER END: compilers/pirc/src/pirerr.c */
 
