@@ -1,5 +1,5 @@
 # Copyright (C) 2001-2006, Parrot Foundation.
-# $Id: auto.pm 36833 2009-02-17 20:09:26Z allison $
+# $Id$
 
 =head1 NAME
 
@@ -7,10 +7,10 @@ config/auto/cpu/i386/auto.pm
 
 =head1 DESCRIPTION
 
-Test for MMX/SSE functionality. Creates these Config entries
+Test for cmpxchg ASM functionality. Creates these Config entries
 
  TEMP_generated => 'files ...'   for inclusion in platform.c or platform.h
- i386_has_mmx   => 1
+ i386_has_gcc_cmpxchg_c   => 1
 
 =cut
 
@@ -24,25 +24,7 @@ sub runstep {
 
     my $verbose = $conf->options->get('verbose');
 
-    my @files = qw( memcpy_mmx.c memcpy_sse.c );
-    for my $f (@files) {
-        print " $f " if $verbose;
-        my ($suffix) = $f =~ /memcpy_(\w+)/;
-        my $path_f = "config/auto/cpu/i386/$f";
-        $conf->cc_gen($path_f);
-        eval( $conf->cc_build("-DPARROT_CONFIG_TEST") );
-        if ($@) {
-            print " $@ " if $verbose;
-        }
-        else {
-            if ( $conf->cc_run() =~ /ok/ ) {
-                _handle_cc_run_ok($conf, $suffix, $path_f, $verbose);
-            }
-        }
-        $conf->cc_clean();
-    }
-
-    @files = qw( test_gcc_cmpxchg_c.in );
+    my @files = qw( test_gcc_cmpxchg_c.in );
     for my $f (@files) {
         print " $f " if $verbose;
         my ($suffix) = $f =~ /test_(\w+)/;
