@@ -1,5 +1,5 @@
 # Copyright (C) 2001-2003, Parrot Foundation.
-# $Id: format.pm 38372 2009-04-26 13:53:17Z jkeenan $
+# $Id$
 
 =head1 NAME
 
@@ -15,7 +15,6 @@ package auto::format;
 
 use strict;
 use warnings;
-use Config;  # for long double printf format
 
 use base qw(Parrot::Configure::Step);
 
@@ -75,8 +74,9 @@ sub _set_floatvalfmt_nvsize {
         # Stay way from long double for now (it may be 64 or 80 bits)
         # die "long double not supported at this time, use double.";
         $nvsize   = $ldsize;
-        if (defined($Config{'sPRIgldbl'})) {
-            $nvformat = "%.15" .  $Config{'sPRIgldbl'};
+        my $spri = $conf->data->get('sPRIgldbl_provisional');
+        if ( defined $spri ) {
+            $nvformat = "%.15" .  $spri;
             $nvformat =~ s/"//g;   # Perl 5's Config value has embedded double quotes
         }
         else {
