@@ -1,5 +1,5 @@
 # Copyright (C) 2008, Parrot Foundation.
-# $Id: gettext.pm 39893 2009-07-05 22:12:36Z jkeenan $
+# $Id$
 
 =head1 NAME
 
@@ -50,7 +50,7 @@ sub runstep {
         return 1;
     }
 
-    my $osname = $conf->data->get_p5('OSNAME');
+    my $osname = $conf->data->get('osname');
 
     my $extra_libs = $self->_select_lib( {
         conf            => $conf,
@@ -61,11 +61,6 @@ sub runstep {
         default         => defined $conf->data->get('glibc') ? '' : '-lintl',
     } );
 
-    # On OS X check the presence of the gettext header in the standard
-    # Fink and MacPorts locations.
-    $self->_handle_darwin_for_fink($conf, $osname, 'libintl.h');
-    $self->_handle_darwin_for_macports($conf, $osname, 'libintl.h');
-
     $conf->cc_gen('config/auto/gettext/gettext_c.in');
     eval { $conf->cc_build( q{}, $extra_libs ); };
     my $has_gettext = 0;
