@@ -1,5 +1,5 @@
 # Copyright (C) 2001-2003, Parrot Foundation.
-# $Id: headers.pm 37201 2009-03-08 12:07:48Z fperrad $
+# $Id$
 
 =head1 NAME
 
@@ -73,7 +73,7 @@ sub runstep {
 
 sub _set_from_Config {
     my $conf = shift;
-    # perl5's Configure system doesn't call this by its full name, which may
+    # Perl 5's Configure system doesn't call this by its full name, which may
     # confuse use later, particularly once we break free and start doing all
     # probing ourselves
     my %mapping = ( i_niin => "i_netinetin" );
@@ -85,7 +85,7 @@ sub _set_from_Config {
 
 sub _list_extra_headers {
     my $conf = shift;
-    # some headers may not be probed-for by perl 5, or might not be
+    # some headers may not be probed-for by Perl 5, or might not be
     # properly reflected in %Config (i_fcntl seems to be wrong on my machine,
     # for instance).
     #
@@ -101,9 +101,19 @@ sub _list_extra_headers {
         sys/stat.h sysexit.h limits.h);
 
     # more extra_headers needed on mingw/msys; *BSD fails if they are present
-    if ( $conf->data->get_p5('OSNAME') eq "msys" ) {
+    if ( $conf->data->get('OSNAME_provisional') eq "msys" ) {
         push @extra_headers, qw(sysmman.h netdb.h);
     }
+
+    if ( $conf->data->get('OSNAME_provisional') eq "MSWin32" ) {
+        # Microsoft provides two annotations mechanisms.  __declspec, which
+        # has been around for a while, and Microsoft's standard source code
+        # annotation language (SAL), introduced with Visual C++ 8.0.  See
+        # <http://msdn2.microsoft.com/en-us/library/ms235402(VS.80).aspx>,
+        # <http://msdn2.microsoft.com/en-us/library/dabb5z75(VS.80).aspx>.
+        push @extra_headers, qw(sal.h);
+    }
+
     return @extra_headers;
 }
 
