@@ -1,5 +1,5 @@
 # Copyright (C) 2001-2008, Parrot Foundation.
-# $Id: pmc.pm 38471 2009-05-04 22:47:15Z cotto $
+# $Id$
 
 =head1 NAME
 
@@ -77,7 +77,7 @@ END
         $parent_dumps .= "src/pmc/$_.dump "
             foreach reverse( ( $self->pmc_parents($pmc) ) );
         my $parent_headers = '';
-        $parent_headers .= "src/pmc/pmc_$_.h "
+        $parent_headers .= "include/pmc/pmc_$_.h "
             for $self->pmc_parents($pmc);
 
         # add dependencies that result from METHOD usage.
@@ -86,7 +86,7 @@ END
         if (contains_pccmethod($pmc_fname)) {
             $pccmethod_depend = 'lib/Parrot/Pmc2c/PCCMETHOD.pm';
             if ($pmc ne 'fixedintegerarray') {
-                $pccmethod_depend .= ' src/pmc/pmc_fixedintegerarray.h';
+                $pccmethod_depend .= ' include/pmc/pmc_fixedintegerarray.h';
             }
         }
         my $include_headers = get_includes($pmc_fname);
@@ -98,15 +98,16 @@ src/pmc/$pmc.c : src/pmc/$pmc.dump
 src/pmc/$pmc.dump : vtable.dump $parent_dumps src/pmc/$pmc.pmc \$(PMC2C_FILES) $pccmethod_depend
 \t\$(PMC2CD) src/pmc/$pmc.pmc
 
-src/pmc/pmc_$pmc.h: src/pmc/$pmc.c
+\$(PMC_INC_DIR)/pmc/pmc_$pmc.h: src/pmc/$pmc.c
 
-src/pmc/$pmc\$(O): src/pmc/$pmc.str \$(NONGEN_HEADERS) \\
-    $parent_headers $include_headers src/pmc/pmc_continuation.h
+src/pmc/$pmc\$(O): include/pmc/pmc_${pmc}.h src/pmc/$pmc.str \$(NONGEN_HEADERS) \\
+    $parent_headers $include_headers include/pmc/pmc_continuation.h \\
+    include/pmc/pmc_callcontext.h include/pmc/pmc_fixedintegerarray.h
 
 END
     }
 
-    # src/pmc/$pmc\$(O): \$(NONGEN_HEADERS) $parent_headers src/pmc/pmc_$pmc.h
+    # src/pmc/$pmc\$(O): \$(NONGEN_HEADERS) $parent_headers include/pmc/pmc_$pmc.h
 
     # build list of libraries for link line in Makefile
     my $slash = $conf->data->get('slash');
@@ -172,6 +173,7 @@ PMC: for my $pmc_file ( split( /\s+/, $pmc_list ) ) {
         TEMP_pmc_classes_o   => $TEMP_pmc_classes_o,
         TEMP_pmc_classes_str => $TEMP_pmc_classes_str,
         TEMP_pmc_classes_pmc => $TEMP_pmc_classes_pmc,
+        pmc_inc              => 'include',
     );
 
     return 1;
@@ -271,6 +273,8 @@ sub get_includes {
           $include = "include/" . $include;
         } elsif ($include =~ m/^pmc_|\.str$/) { # local pmc header
           $include = "src/pmc/" . $include;
+        } elsif ($include =~ m/^pmc\/pmc_|\.h$/) { # local pmc header
+          $include = "include/" . $include;
         } # else it's probably a system header, don't depend on it.
         push @retval, $include;
     }
