@@ -1,5 +1,5 @@
 # Copyright (C) 2006-2007, Parrot Foundation.
-# $Id: socklen_t.pm 37201 2009-03-08 12:07:48Z fperrad $
+# $Id$
 
 =head1 NAME
 
@@ -43,7 +43,7 @@ sub _probe_for_socklen_t {
     my $conf = shift;
     return $conf->data->get('has_socklen_t')
             ||
-           $conf->data->get_p5('d_socklen_t');
+           $conf->data->get('d_socklen_t_provisional');
 }
 
 sub _evaluate_socklen_t {
