@@ -1,5 +1,5 @@
 # Copyright (C) 2008, Parrot Foundation.
-# $Id: opengl.pm 40145 2009-07-18 17:36:32Z petdance $
+# $Id$
 
 =head1 NAME
 
@@ -145,12 +145,14 @@ my %C_TYPE = (
     AGLRendererInfo         => 'void*',
     AGLPbuffer              => 'void*',
     GDHandle                => 'void*',
+    IOSurfaceRef            => 'void*',
     WindowRef               => 'void*',
     HIViewRef               => 'void*',
     Style                   => 'void*',
     HANDLE                  => 'void*',
     HPBUFFERARB             => 'void*',
     HPBUFFEREXT             => 'void*',
+    HVIDEOINPUTDEVICENV     => 'void*',
     HVIDEOOUTPUTDEVICENV    => 'void*',
     HPVIDEODEV              => 'void*',
     HPGPUNV                 => 'void*',
@@ -162,6 +164,7 @@ my %C_TYPE = (
     LPPIXELFORMATDESCRIPTOR => 'void*',
     LPVOID                  => 'void*',
     PGPU_DEVICE             => 'void*',
+    GLsync                  => 'void*',
 
     GLchar                  => 'char',
     GLcharARB               => 'char',
@@ -222,10 +225,13 @@ my %C_TYPE = (
     GLXPbufferSGIX          => 'unsigned long',
     GLXFBConfigIDSGIX       => 'unsigned long',
     GLXVideoSourceSGIX      => 'unsigned long',
+    GLXVideoCaptureDeviceNV => 'unsigned long',
 
     int64_t                 => 'long long',
     INT64                   => 'long long',
+    GLint64                 => 'signed long long',
     GLint64EXT              => 'signed long long',
+    GLuint64                => 'unsigned long long',
     GLuint64EXT             => 'unsigned long long',
 
     FLOAT                   => 'float',
@@ -249,7 +255,7 @@ my %NCI_TYPE = (
     long         => 'l',
     size_t       => 'l',
     ptrdiff_t    => 'l',
-    # Requires RT 53406
+    # Requires TT #1182
     # longlong     => 'L',
     float        => 'f',
     double       => 'd',
@@ -276,6 +282,24 @@ my %NCI_TYPE = (
     'double***'  => 'p',
 );
 
+my %PCC_TYPE = (
+    c => 'I',
+    s => 'I',
+    i => 'I',
+    l => 'I',
+    f => 'N',
+    d => 'N',
+    t => 'S',
+    p => 'P',
+);
+
+my %PCC_CAST = (
+    I => '(INTVAL) ',
+    N => '(FLOATVAL) ',
+    S => '',
+    P => '',
+);
+
 my %OVERRIDE = (
     'glutInit'  => 'v3p',
 );
@@ -324,12 +348,14 @@ my @IGNORE = (
     'GetPixelFormat',
     'SetPixelFormat',
 
-    # Can't handle longlong until RT 53406 is done
+    # Can't handle longlong until TT #1182 is done
     'glBufferAddressRangeNV',
+    'glClientWaitSync',
     'glUniformui64NV',
     'glProgramUniformui64NV',
     'glPresentFrameKeyedNV',
     'glPresentFrameDualFillNV',
+    'glWaitSync',
     'glXSwapBuffersMscOML',
     'glXWaitForMscOML',
     'glXWaitForSbcOML',
@@ -403,6 +429,9 @@ my @SKIP = (
     'GLwDrawAP.h',
     'GLwMDrawA.h',
     'GLwMDrawAP.h',
+
+    # GLFW, a replacement for GLUT
+    'glfw.h',
 );
 
 my $MACRO_FILE = 'runtime/parrot/include/opengl_defines.pasm';
@@ -432,7 +461,7 @@ sub runstep {
 
     my @include_paths_win32 = grep /\S/ => split /;/ => ($ENV{INCLUDE} || '');
 
-    my $osname = $conf->data->get_p5('OSNAME');
+    my $osname = $conf->data->get('osname');
     if (scalar @include_paths_win32 == 0 && $osname =~ /mswin32/i) {
         my $cc = $conf->data->get('cc');
         my $path = dirname(dirname(which($cc))) . '\include';
@@ -458,6 +487,7 @@ sub runstep {
 
 #         # Portability testing headers
 #         "$ENV{HOME}/src/gentoo3/*.h",
+#         "$ENV{HOME}/src/gentoo4/usr/include/GL/*.h",
 #         "$ENV{HOME}/src/osx/headers/GLUT/*.h",
 #         "$ENV{HOME}/src/osx/headers/OpenGL/*.h",
 #         "$ENV{HOME}/src/osx-10.4/GLUT/*.h",
@@ -550,6 +580,9 @@ sub gen_opengl_defines {
             if ($F[2] =~ /^(?:[ACW])?GL[A-Z]*_\w+$/) {
                 push @macros, [$api, $F[1], $F[2]];
             }
+            if ($F[2] =~ /^\(?((?:[ACW])?GL[A-Z]*_\w+)([+-]\d+(?:\.\d*)?(?:e\d+)?)\)?$/) {
+                push @macros, [$api, $F[1], $1, $2];
+            }
             elsif (   $F[2] =~ /^0x[0-9a-fA-F]+$/
                    || $F[2] =~ /^\d+(?:\.\d*)?(?:e\d+)?$/) {
                 $defs{$api}{$F[1]} = $F[2];
@@ -562,15 +595,17 @@ sub gen_opengl_defines {
     }
 
     foreach my $macro (@macros) {
-        my ($api, $define, $value) = @$macro;
+        my ($api, $define, $value, $offset) = @$macro;
         my ($val_api) = $value =~ /^((?:[ACW])?GL[A-Z]*)_/;
 
-        unless (defined ($defs{$api}{$define} = $defs{$val_api}{$value})) {
-            delete $defs{$api}{$define};
+        unless (defined $defs{$val_api}{$value}) {
             next if $non_numeric{$define};
 
-            die "'$define' is defined as '$value', but no '$value' has been defined";
+            die "'$define' is defined using '$value', but no '$value' has been defined";
         }
+
+        $defs{$api}{$define}  = $defs{$val_api}{$value};
+        $defs{$api}{$define} += $offset if defined $offset;
     }
 
     open my $macros, '>', $MACRO_FILE
@@ -628,6 +663,9 @@ sub gen_opengl_wrappers {
             next if     /^#/;
             next if     /\btypedef\b/;
 
+            # Skip where we are explicitly told to do so
+            next if /\bFGUNUSED\b/;
+
             # Save a (space compressed) copy of the source line
             # for later error reporting
             my $orig =  $_;
@@ -636,7 +674,8 @@ sub gen_opengl_wrappers {
 
             # Get rid of junk needed for C, but not for Parrot NCI;
             # also do general cleanup to make parsing easier
-            s/\b(?:AVAILABLE|DEPRECATED_FOR)_MAC_OS_X_VERSION_\d+_\d+_AND_LATER\b\s*//;
+            s/\b(?:AVAILABLE|DEPRECATED_(?:IN|FOR))_MAC_OS_X_VERSION_\d+_\d+_AND_LATER\b\s*//;
+            s/\bAVAILABLE_MAC_OS_X_VERSION_\d+_\d+_AND_LATER_BUT_DEPRECATED_IN_MAC_OS_X_VERSION_\d+_\d+\b\s*//;
             s/\b__cdecl\b\s*//;
             s/\b__stdcall\b\s*//;
             s/\b_CRTIMP\b\s*//;
@@ -921,15 +960,16 @@ sub gen_glut_callbacks {
 
         my $args   =  $params;
            $args   =~ s/void//;
-           $args   =~ s/(^|, )(\w+ )+/$1/g;
+           $args   =~ s/unsigned //;
+           $args   =~ s/(^|, )((?:\w+ )+)/$1$PCC_CAST{$PCC_TYPE{$NCI_TYPE{(split ' ', $2)[0]}}}/g;
            $args   =  ", $args" if $args;
         my $proto  =  $params;
            $proto  =~ s/ \w+(,|$)/$1/g;
         my $sig    =  $proto;
            $sig    =~ s/void//;
            $sig    =~ s/unsigned //;
-           $sig    =~ s/(\w)\w+\W*/$1/g;
-           $sig    =  "v$sig";
+           $sig    =~ s/(\w+)\W*/$PCC_TYPE{$NCI_TYPE{$1}}/g;
+           $sig    =  "$sig->";
 
         my $glutcb =  "glutcb${friendly}Func";
            $glutcb =~ s/ //g;
@@ -995,6 +1035,7 @@ cannot be used.
 #define PARROT_IN_EXTENSION
 
 #include "parrot/parrot.h"
+#include "parrot/extend.h"
 #include <$glut_header>
 
 
@@ -1064,7 +1105,7 @@ glut_timer_func(int data)
     PMC           *sub   = callback_data[GLUT_CB_TIMER].sub;
 
     if (is_safe(interp, sub))
-        Parrot_runops_fromc_args_event(interp, sub, "vi", data);
+        Parrot_ext_call(interp, sub, "I->", (INTVAL) data);
 }
 
 PARROT_DYNEXT_EXPORT
@@ -1099,7 +1140,8 @@ glut_joystick_func(unsigned int buttons, int xaxis, int yaxis, int zaxis)
     PMC           *sub   = callback_data[GLUT_CB_JOYSTICK].sub;
 
     if (is_safe(interp, sub))
-        Parrot_runops_fromc_args_event(interp, sub, "viiii", buttons, xaxis, yaxis, zaxis);
+        Parrot_ext_call(interp, sub, "IIII->",
+            (INTVAL) buttons, (INTVAL) xaxis, (INTVAL) yaxis, (INTVAL) zaxis);
 }
 
 PARROT_DYNEXT_EXPORT
@@ -1139,7 +1181,7 @@ $_->{thunk}($_->{params})
     PMC           *sub   = callback_data[$_->{enum}].sub;
 
     if (is_safe(interp, sub))
-        Parrot_runops_fromc_args_event(interp, sub, "$_->{sig}"$_->{args});
+        Parrot_ext_call(interp, sub, "$_->{sig}"$_->{args});
 }
 
 PARROT_DYNEXT_EXPORT
