@@ -1,5 +1,5 @@
 /*
- * $Id: exec.c 37786 2009-03-28 01:09:22Z coke $
+ * $Id$
  * Copyright (C) 2004-2008, Parrot Foundation.
  */
 
@@ -11,7 +11,7 @@ config/gen/platform/ansi/exec.c
 
 =head1 DESCRIPTION
 
-RT#48264
+Functions for dealing with child processes and Execs. (Currently not implemented on this platform.)
 
 =head2 Functions
 
@@ -57,21 +57,6 @@ Parrot_Run_OS_Command_Argv(PARROT_INTERP, PMC *cmdargs)
 
 /*
 
-=item C<void Parrot_Exec_OS_Comman(PARROT_INTERP, STRING *command)>
-
-=cut
-
-*/
-
-void
-Parrot_Exec_OS_Comman(PARROT_INTERP, STRING *command)
-{
-  Parrot_ex_throw_from_c_args(interp, NULL, EXCEPTION_NOSPAWN,
-         "Exec not implemented");
-}
-
-/*
-
 =back
 
 =cut
