@@ -1,5 +1,5 @@
 /*
- * $Id: env.c 37877 2009-04-02 20:20:22Z coke $
+ * $Id$
  * Copyright (C) 2004-2006, Parrot Foundation.
  */
 
@@ -33,8 +33,10 @@ Environment manipulation stuff
 */
 
 void
-Parrot_setenv(const char *name, const char *value)
+Parrot_setenv(PARROT_INTERP, STRING *str_name, STRING *str_value)
 {
+    char *name  = Parrot_str_to_cstring(interp, str_name);
+    char *value = Parrot_str_to_cstring(interp, str_value);
 #ifdef PARROT_HAS_SETENV
     setenv(name, value, 1);
 #else
@@ -52,9 +54,9 @@ Parrot_setenv(const char *name, const char *value)
     strcpy(envs + name_len + 1, value);
 
     putenv(envs);
-
-    /* The buffer is intentionally not freed! */
 #endif
+    Parrot_str_free_cstring(name);
+    Parrot_str_free_cstring(value);
 }
 
 /*
@@ -66,13 +68,15 @@ Parrot_setenv(const char *name, const char *value)
 */
 
 void
-Parrot_unsetenv(const char *name)
+Parrot_unsetenv(PARROT_INTERP, STRING *str_name)
 {
+    char *name = Parrot_str_to_cstring(interp, str_name);
 #ifdef PARROT_HAS_UNSETENV
     unsetenv(name);
 #else
     Parrot_setenv(name, "");
 #endif
+    Parrot_str_free_cstring(name);
 }
 
 /*
@@ -84,10 +88,12 @@ Parrot_unsetenv(const char *name)
 */
 
 char *
-Parrot_getenv(const char *name, int *free_it)
+Parrot_getenv(PARROT_INTERP, STRING *str_name)
 {
-    *free_it = 0;
-    return getenv(name);
+    char *name  = Parrot_str_to_cstring(interp, str_name);
+    char *value = getenv(name);
+    Parrot_str_free_cstring(name);
+    return value;
 }
 
 /*
