@@ -1,5 +1,5 @@
 /*
- * $Id: threads.h 37201 2009-03-08 12:07:48Z fperrad $
+ * $Id$
  * Copyright (C) 2004-2007, Parrot Foundation.
  */
 
@@ -9,16 +9,18 @@
  * POSIX threading stuff
  */
 
-#ifdef PARROT_HAS_HEADER_PTHREAD
-#  include "parrot/thr_pthread.h"
-#endif
+#ifdef PARROT_HAS_THREADS
 
-#ifdef PARROT_HAS_HEADER_UNISTD
-#  include <unistd.h>
-#  ifdef _POSIX_PRIORITY_SCHEDULING
-#    define YIELD sched_yield()
-#  endif
-#endif
+#  include "parrot/thr_pthread.h"
+
+#  ifdef PARROT_HAS_HEADER_UNISTD
+#    include <unistd.h>
+#    ifdef _POSIX_PRIORITY_SCHEDULING
+#      define YIELD sched_yield()
+#    endif
+#  endif /* PARROT_HAS_HEADER_UNISTD */
+
+#endif /* PARROT_HAS_THREADS */
 
 #endif /* PARROT_PLATFORM_GENERIC_THREADS_H_GUARD */
 
