@@ -1,5 +1,5 @@
 # Copyright (C) 2005-2008, Parrot Foundation.
-# $Id: dec_osf.pm 37201 2009-03-08 12:07:48Z fperrad $
+# $Id$
 
 package init::hints::dec_osf;
 
@@ -11,7 +11,7 @@ sub runstep {
 
     # Tru64
     my $ccflags = $conf->data->get('ccflags');
-    if ( $ccflags !~ /-pthread/ ) {
+    if ( $ccflags !~ /-pthread\b/ ) {
         $ccflags .= ' -pthread';
     }
     if ( $ccflags !~ /-D_REENTRANT/ ) {
@@ -24,7 +24,7 @@ sub runstep {
     $conf->data->set( ccflags => $ccflags );
 
     my $libs = $conf->data->get('libs');
-    if ( $libs !~ /-lpthread/ ) {
+    if ( $libs !~ /-lpthread\b/ ) {
         $libs .= ' -lpthread';
     }
     $conf->data->set( libs => $libs );
@@ -37,7 +37,7 @@ sub runstep {
     }
 
     my $linkflags = $conf->data->get('linkflags');
-    if ( $linkflags !~ /-expect_unresolved/ ) {
+    if ( $linkflags !~ /-expect_unresolved\b/ ) {
         $linkflags = "-expect_unresolved '*' -O4 -msym -std $linkflags";
         $conf->data->set( linkflags => $linkflags );
     }
