@@ -1,5 +1,5 @@
 # Copyright (C) 2005-2007, Parrot Foundation.
-# $Id: linux.pm 39871 2009-07-03 14:40:18Z jkeenan $
+# $Id$
 
 package init::hints::linux;
 
@@ -23,9 +23,12 @@ sub runstep {
     # should find g++ in most cases
     my $link = $conf->data->get('link') || 'c++';
 
-    if ( $libs !~ /-lpthread/ ) {
+    if ( $libs !~ /-lpthread\b/ ) {
         $libs .= ' -lpthread';
     }
+    if ( $libs !~ /-lrt\b/ ) {
+        $libs .= ' -lrt';
+    }
     my $ld_share_flags = $conf->data->get('ld_share_flags');
     my $cc_shared      = $conf->data->get('cc_shared');
 
@@ -33,75 +36,11 @@ sub runstep {
 
         # Intel C++ compiler has the same name as its C compiler
         $link = $cc;
-
-        # suppress sprintf warnings that don't apply
-        $ccflags .= ' -wd269';
-
-        # suppress remarks about floating point comparisons
-        $ccflags .= ' -wd1572';
-
-        # suppress remarks about hiding of parameter declarations
-        $ccflags .= ' -wd1599';
-
-        # suppress remarks about "argument is incompatible with corresponding
-        # format string conversion"
-        $ccflags .= ' -wd181';
-
-        # gcc is currently not looking for unused variables, so should icc
-        # for the time being (this will reduce the noise somewhat)
-        $ccflags .= ' -wd869';
-
-        # ignore "operands are evaluated in unspecified order" warning
-        $ccflags .= ' -wd981';
-
-        # ignore "external declaration in primary source file"
-        # (only done temporarily to reduce noise)
-        $ccflags .= ' -wd1419';
-
-        # ignore "function 'xxx' was declared but never referenced"
-        # (only done temporarily to reduce noise)
-        $ccflags .= ' -wd117';
-
-        # ignore "conversion from "" to "" may lose significant bits"
-        # warnings (only done temporarily to reduce noise)
-        $ccflags .= ' -wd810';
-
-        # ignore "function "" was declared but never referenced"
-        # warnings (only done temporarily to reduce noise)
-        $ccflags .= ' -wd177';
-
-        # ignore warnings springing from problems with computed goto
-        # statements.  If someone can find out how to make icc play nicely
-        # in these situations, that would be good.
-        $ccflags .= ' -wd1296';
-
-        $ccflags .= ' -Wall -Wcheck -w2';
-
-        $ccflags .= ' -Wabi';
-        $ccflags .= ' -Wcomment';
-        $ccflags .= ' -Wdeprecated';
-        $ccflags .= ' -Wmain';
-        $ccflags .= ' -Wmissing-prototypes';
-
-        #$ccflags .= ' -Wp64';
-        $ccflags .= ' -Wpointer-arith';
-        $ccflags .= ' -Wreturn-type';
-        $ccflags .= ' -Wstrict-prototypes';
-
-        #$ccflags .= ' -Wtrigraphs';
-        $ccflags .= ' -Wuninitialized';
-        $ccflags .= ' -Wunknown-pragmas';
-        $ccflags .= ' -Wunused-function';
-        $ccflags .= ' -Wunused-variable';
-
-        # enable correct floating point behavior
-        # which is *not* the default behavior. ahem.
-        $ccflags .= ' -we147';
-
         $ld_share_flags = ' -shared -g -pipe -fexceptions -fPIC';
         $cc_shared .= ' -fPIC';
 
-        $verbose and print " ccflags: $ccflags\n";
+        $ccflags = _handle_icc_ccflags($ccflags, $verbose);
+
     }
     elsif ( $cc =~ /suncc/ ) {
         $link = 'sunCC';
@@ -149,13 +88,84 @@ sub runstep {
         libparrot_soname       => "-Wl,-soname=libparrot$share_ext.$version",
     );
 
-     if ( ( split( m/-/, $conf->data->get_p5('archname'), 2 ) )[0] eq 'ia64' ) {
+     if ( ( split( m/-/, $conf->data->get('archname_provisional'), 2 ) )[0] eq 'ia64' ) {
 
         $conf->data->set( platform_asm => 1 );
     }
     return;
 }
 
+sub _handle_icc_ccflags {
+    my ($ccflags, $verbose) = @_;
+
+    # suppress sprintf warnings that don't apply
+    $ccflags .= ' -wd269';
+
+    # suppress remarks about floating point comparisons
+    $ccflags .= ' -wd1572';
+
+    # suppress remarks about hiding of parameter declarations
+    $ccflags .= ' -wd1599';
+
+    # suppress remarks about "argument is incompatible with corresponding
+    # format string conversion"
+    $ccflags .= ' -wd181';
+
+    # gcc is currently not looking for unused variables, so should icc
+    # for the time being (this will reduce the noise somewhat)
+    $ccflags .= ' -wd869';
+
+    # ignore "operands are evaluated in unspecified order" warning
+    $ccflags .= ' -wd981';
+
+    # ignore "external declaration in primary source file"
+    # (only done temporarily to reduce noise)
+    $ccflags .= ' -wd1419';
+
+    # ignore "function 'xxx' was declared but never referenced"
+    # (only done temporarily to reduce noise)
+    $ccflags .= ' -wd117';
+
+    # ignore "conversion from "" to "" may lose significant bits"
+    # warnings (only done temporarily to reduce noise)
+    $ccflags .= ' -wd810';
+
+    # ignore "function "" was declared but never referenced"
+    # warnings (only done temporarily to reduce noise)
+    $ccflags .= ' -wd177';
+
+    # ignore warnings springing from problems with computed goto
+    # statements.  If someone can find out how to make icc play nicely
+    # in these situations, that would be good.
+    $ccflags .= ' -wd1296';
+
+    $ccflags .= ' -Wall -Wcheck -w2';
+
+    $ccflags .= ' -Wabi';
+    $ccflags .= ' -Wcomment';
+    $ccflags .= ' -Wdeprecated';
+    $ccflags .= ' -Wmain';
+    $ccflags .= ' -Wmissing-prototypes';
+
+    #$ccflags .= ' -Wp64';
+    $ccflags .= ' -Wpointer-arith';
+    $ccflags .= ' -Wreturn-type';
+    $ccflags .= ' -Wstrict-prototypes';
+
+    #$ccflags .= ' -Wtrigraphs';
+    $ccflags .= ' -Wuninitialized';
+    $ccflags .= ' -Wunknown-pragmas';
+    $ccflags .= ' -Wunused-function';
+    $ccflags .= ' -Wunused-variable';
+
+    # enable correct floating point behavior
+    # which is *not* the default behavior. ahem.
+    $ccflags .= ' -we147';
+
+    $verbose and print " ccflags: $ccflags\n";
+    return $ccflags;
+}
+
 1;
 
 # Local Variables:
