@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2001-2008, Parrot Foundation.
-$Id: test_main.c 37201 2009-03-08 12:07:48Z fperrad $
+$Id$
 
 =head1 NAME
 
@@ -60,8 +60,7 @@ static void version(void);
 
 /*
 
-=item C<int
-main(int argc, char *argv[])>
+=item C<int main(int argc, char *argv[])>
 
 Loads the file and runs the code.
 
@@ -99,8 +98,7 @@ main(int argc, char *argv[])
 
 /*
 
-=item C<char *
-parseflags(PARROT_INTERP, int *argc, char **argv[])>
+=item C<static char * parseflags(PARROT_INTERP, int *argc, char **argv[])>
 
 Parses the command-line.
 
@@ -133,48 +131,48 @@ parseflags(PARROT_INTERP, int *argc, char **argv[])
         }
 
         switch (opt.opt_id) {
-        case 'b':
+          case 'b':
             setopt(PARROT_BOUNDS_FLAG);
             break;
-        case 'j':
+          case 'j':
             setopt(PARROT_JIT_FLAG);
             break;
-        case 'o':
+          case 'o':
             setopt(PARROT_EXEC_FLAG);
             break;
-        case 'p':
+          case 'p':
             setopt(PARROT_PROFILE_FLAG);
             break;
-        case 'P':
+          case 'P':
             setopt(PARROT_PREDEREF_FLAG);
             break;
-        case 'S':
+          case 'S':
             setopt(PARROT_SWITCH_FLAG);
             break;
-        case 'g':
+          case 'g':
             unsetopt(PARROT_CGOTO_FLAG);
             break;
-        case 't':
+          case 't':
             setopt(PARROT_TRACE_FLAG);
             break;
-        case 'd':
+          case 'd':
             setopt(PARROT_DEBUG_FLAG);
             break;
-        case 'h':
+          case 'h':
             usage();
             break;
-        case 'v':
+          case 'v':
             version();
             break;
-        case 'w':
+          case 'w':
             Parrot_setwarnings(interp, PARROT_WARNINGS_ALL_FLAG);
             break;
 
-        case '.':  /* Give Windows Parrot hackers an opportunity to
-                    * attach a debuggger. */
+          case '.':  /* Give Windows Parrot hackers an opportunity to
+                      * attach a debuggger. */
             fgetc(stdin);
             break;
-        case OPT_GC_DEBUG:
+          case OPT_GC_DEBUG:
 #if DISABLE_GC_DEBUG
             Parrot_warn(interp, PARROT_WARNINGS_ALL_FLAG,
                         "PARROT_GC_DEBUG is set but the binary was "
@@ -182,7 +180,7 @@ parseflags(PARROT_INTERP, int *argc, char **argv[])
 #endif
             setopt(PARROT_GC_DEBUG_FLAG);
             break;
-        case OPT_DESTROY_FLAG:
+          case OPT_DESTROY_FLAG:
             setopt(PARROT_DESTROY_FLAG);
             break;
         }
@@ -200,8 +198,7 @@ parseflags(PARROT_INTERP, int *argc, char **argv[])
 
 /*
 
-=item C<static void
-usage(void)>
+=item C<static void usage(void)>
 
 Returns the user help.
 
@@ -244,8 +241,7 @@ usage(void)
 
 /*
 
-=item C<static void
-version(void)>
+=item C<static void version(void)>
 
 Returns the version information.
 
