@@ -1,4 +1,4 @@
-/* $Id: japhc.c 37201 2009-03-08 12:07:48Z fperrad $ */
+/* $Id$ */
 
 /*
  * Copyright (C) 2004-2008, Parrot Foundation.
@@ -45,8 +45,7 @@ PMC* japh_compiler(PARROT_INTERP, const char *s);
 
 /*
 
-=item C<void
-Parrot_lib_japhc_init(PARROT_INTERP, PMC* lib)>
+=item C<void Parrot_lib_japhc_init(PARROT_INTERP, PMC* lib)>
 
 loadlib calls the load and init hooks
 we use init to register the compiler
@@ -68,10 +67,7 @@ Parrot_lib_japhc_init(PARROT_INTERP, PMC* lib)
 
 /*
 
-=item C<static int
-unescape(char *string)>
-
-RT#48260: Not yet documented!!!
+=item C<static int unescape(char *string)>
 
 =cut
 
@@ -85,12 +81,12 @@ unescape(char *string)
     for (start = p = string ; *string; string++) {
         if (*string == '\\' && string[1]) {
             switch (*++string) {
-                case 'n':
-                    *p++ = '\n';
-                    break;
-                default:
-                    *p++ = *string;
-                    break;
+              case 'n':
+                *p++ = '\n';
+                break;
+              default:
+                *p++ = *string;
+                break;
             }
         }
         else
@@ -102,8 +98,8 @@ unescape(char *string)
 
 /*
 
-=item C<static int
-add_const_str(PARROT_INTERP, PackFile_ConstTable *consts, char *str)>
+=item C<static int add_const_str(PARROT_INTERP, PackFile_ConstTable *consts,
+char *str)>
 
 add constant string to constant_table
 
@@ -195,32 +191,32 @@ japh_compiler(PARROT_INTERP, const char *program)
     pc = cur_cs->base.data;
     for (p = program; *p; ++p) {
         switch (*p) {
-            case 'p':        /* print_sc */
-                *pc++ = interp->op_lib->op_code("print_sc", 1);
-                /* const follows */
-                ++p;
-                switch (*p) {
-                    case 'J':
-                        *pc++ = add_const_str(interp, consts, "Just ");
-                        break;
-                    case 'a':
-                        *pc++ = add_const_str(interp, consts, "another ");
-                        break;
-                    case 'P':
-                        *pc++ = add_const_str(interp, consts, "Parrot ");
-                        break;
-                    case 'H':
-                        *pc++ = add_const_str(interp, consts, "Hacker");
-                        break;
-                    case 'n':
-                        *pc++ = add_const_str(interp, consts, "\n");
-                        break;
-                }
+          case 'p':        /* print_sc */
+            *pc++ = interp->op_lib->op_code("print_sc", 1);
+            /* const follows */
+            ++p;
+            switch (*p) {
+              case 'J':
+                *pc++ = add_const_str(interp, consts, "Just ");
                 break;
-            case 'e':        /* end */
-                *pc++ = interp->op_lib->op_code("invoke_p", 1);
-                *pc++ = 1;
+              case 'a':
+                *pc++ = add_const_str(interp, consts, "another ");
                 break;
+              case 'P':
+                *pc++ = add_const_str(interp, consts, "Parrot ");
+                break;
+              case 'H':
+                *pc++ = add_const_str(interp, consts, "Hacker");
+                break;
+              case 'n':
+                *pc++ = add_const_str(interp, consts, "\n");
+                break;
+            }
+            break;
+          case 'e':        /* end */
+            *pc++ = interp->op_lib->op_code("invoke_p", 1);
+            *pc++ = 1;
+            break;
         }
     }
     if (old_cs) {
