@@ -1,5 +1,5 @@
 /* enums.h
- * $Id: enums.h 36833 2009-02-17 20:09:26Z allison $
+ * $Id$
  *  Copyright (C) 2001-2008, Parrot Foundation.
  *  Overview:
  *     enums shared by much of the stack-handling code
@@ -45,22 +45,23 @@ typedef enum {
 /* &gen_from_enum(call_bits.pasm lib/Parrot/Pmc2c/PCCMETHOD_BITS.pm) */
 typedef enum {
     /* 4 low bits are argument types */
-    PARROT_ARG_INTVAL           = 0x000,  /* 0 */
-    PARROT_ARG_STRING           = 0x001,  /* 1 */
-    PARROT_ARG_PMC              = 0x002,  /* 2 */
-    PARROT_ARG_FLOATVAL         = 0x003,  /* 3 */
-    PARROT_ARG_TYPE_MASK        = 0x00f,
+    PARROT_ARG_INTVAL           = 0x0000,  /* 0 */
+    PARROT_ARG_STRING           = 0x0001,  /* 1 */
+    PARROT_ARG_PMC              = 0x0002,  /* 2 */
+    PARROT_ARG_FLOATVAL         = 0x0003,  /* 3 */
+    PARROT_ARG_TYPE_MASK        = 0x000f,
     /* argument meaning and conversion bits */
-    PARROT_ARG_CONSTANT         = 0x010,  /* 16 */
+    PARROT_ARG_CONSTANT         = 0x0010,  /* 16 */
     /* bits a user has to define */
-    PARROT_ARG_FLATTEN          = 0x020,       /* .flatten_arg */
+    PARROT_ARG_FLATTEN          = 0x0020,       /* .flatten_arg */
     PARROT_ARG_SLURPY_ARRAY     = PARROT_ARG_FLATTEN,  /* i.e. foldup  */
     /* unused - 0x040 */
-    PARROT_ARG_OPTIONAL         = 0x080, /* 128 */
-    PARROT_ARG_OPT_FLAG         = 0x100, /* 256 prev optional was set */
-    PARROT_ARG_NAME             = 0x200, /* 512 this String is an arg name */
-    PARROT_ARG_LOOKAHEAD        = 0x400, /* 1024 this is a lookahead argument */
-    PARROT_ARG_INVOCANT         = 0x800  /* 2048 this PMC is an invocant */
+    PARROT_ARG_OPTIONAL         = 0x0080, /* 128 */
+    PARROT_ARG_OPT_FLAG         = 0x0100, /* 256 prev optional was set */
+    PARROT_ARG_NAME             = 0x0200, /* 512 this String is an arg name */
+    PARROT_ARG_LOOKAHEAD        = 0x0400, /* 1024 this is a lookahead argument */
+    PARROT_ARG_INVOCANT         = 0x0800,  /* 2048 this PMC is an invocant */
+    PARROT_ARG_CALL_SIG         = 0x1000
     /* more to come soon */
 
 } Call_bits_enum_t;
