@@ -1,7 +1,7 @@
 /* exceptions.h
  *  Copyright (C) 2001-2008, Parrot Foundation.
  *  SVN Info
- *     $Id: exceptions.h 37201 2009-03-08 12:07:48Z fperrad $
+ *     $Id$
  *  Overview:
  *     define the internal interpreter exceptions
  *  Data Structure and Algorithms:
@@ -24,76 +24,77 @@
 
 /* &gen_from_enum(except_types.pasm) */
 typedef enum {
-        EXCEPTION_BAD_BUFFER_SIZE,
-        EXCEPTION_MISSING_ENCODING_NAME,
-        EXCEPTION_INVALID_STRING_REPRESENTATION,
-        EXCEPTION_ICU_ERROR,
-        EXCEPTION_UNIMPLEMENTED,
+    EXCEPTION_BAD_BUFFER_SIZE,
+    EXCEPTION_MISSING_ENCODING_NAME,
+    EXCEPTION_INVALID_STRING_REPRESENTATION,
+    EXCEPTION_ICU_ERROR,
+    EXCEPTION_UNIMPLEMENTED,
 
-        EXCEPTION_NULL_REG_ACCESS,
-        EXCEPTION_NO_REG_FRAMES,
-        EXCEPTION_SUBSTR_OUT_OF_STRING,
-        EXCEPTION_ORD_OUT_OF_STRING,
-        EXCEPTION_MALFORMED_UTF8,
-        EXCEPTION_MALFORMED_UTF16,
-        EXCEPTION_MALFORMED_UTF32,
-        EXCEPTION_INVALID_CHARACTER,
-        EXCEPTION_INVALID_CHARTYPE,
-        EXCEPTION_INVALID_ENCODING,
-        EXCEPTION_INVALID_CHARCLASS,
-        EXCEPTION_NEG_REPEAT,
-        EXCEPTION_NEG_SUBSTR,
-        EXCEPTION_NEG_SLEEP,
-        EXCEPTION_NEG_CHOP,
-        EXCEPTION_INVALID_OPERATION,
-        EXCEPTION_ARG_OP_NOT_HANDLED,
-        EXCEPTION_KEY_NOT_FOUND,
-        EXCEPTION_JIT_UNAVAILABLE,
-        EXCEPTION_EXEC_UNAVAILABLE,
-        EXCEPTION_INTERP_ERROR,
-        EXCEPTION_PREDEREF_LOAD_ERROR,
-        EXCEPTION_PARROT_USAGE_ERROR,
-        EXCEPTION_PIO_ERROR,
-        EXCEPTION_PARROT_POINTER_ERROR,
-        EXCEPTION_DIV_BY_ZERO,
-        EXCEPTION_PIO_NOT_IMPLEMENTED,
-        EXCEPTION_ALLOCATION_ERROR,
-        EXCEPTION_INTERNAL_PANIC,
-        EXCEPTION_OUT_OF_BOUNDS,
-        EXCEPTION_JIT_ERROR,
-        EXCEPTION_EXEC_ERROR,
-        EXCEPTION_ILL_INHERIT,
-        EXCEPTION_NO_PREV_CS,
-        EXCEPTION_NO_CLASS,
-        EXCEPTION_LEX_NOT_FOUND,
-        EXCEPTION_PAD_NOT_FOUND,
-        EXCEPTION_ATTRIB_NOT_FOUND,
-        EXCEPTION_GLOBAL_NOT_FOUND,
-        EXCEPTION_EXTERNAL_ERROR,
-        EXCEPTION_METHOD_NOT_FOUND,
-        EXCEPTION_VTABLE_NOT_FOUND,
-        EXCEPTION_WRITE_TO_CONSTCLASS,
-        EXCEPTION_NOSPAWN,
-        EXCEPTION_INTERNAL_NOT_IMPLEMENTED,
-        EXCEPTION_ERR_OVERFLOW,
-        EXCEPTION_LOSSY_CONVERSION,
-        EXCEPTION_ROLE_COMPOSITION_METHOD_CONFLICT,
-        EXCEPTION_UNEXPECTED_NULL,
-        EXCEPTION_LIBRARY_ERROR,
-        EXCEPTION_LIBRARY_NOT_LOADED,
-        EXCEPTION_SYNTAX_ERROR,
-        EXCEPTION_MALFORMED_PACKFILE,
+    EXCEPTION_NULL_REG_ACCESS,
+    EXCEPTION_NO_REG_FRAMES,
+    EXCEPTION_SUBSTR_OUT_OF_STRING,
+    EXCEPTION_ORD_OUT_OF_STRING,
+    EXCEPTION_MALFORMED_UTF8,
+    EXCEPTION_MALFORMED_UTF16,
+    EXCEPTION_MALFORMED_UTF32,
+    EXCEPTION_INVALID_CHARACTER,
+    EXCEPTION_INVALID_CHARTYPE,
+    EXCEPTION_INVALID_ENCODING,
+    EXCEPTION_INVALID_CHARCLASS,
+    EXCEPTION_NEG_REPEAT,
+    EXCEPTION_NEG_SUBSTR,
+    EXCEPTION_NEG_SLEEP,
+    EXCEPTION_NEG_CHOP,
+    EXCEPTION_INVALID_OPERATION,
+    EXCEPTION_ARG_OP_NOT_HANDLED,
+    EXCEPTION_KEY_NOT_FOUND,
+    EXCEPTION_JIT_UNAVAILABLE,
+    EXCEPTION_EXEC_UNAVAILABLE,
+    EXCEPTION_INTERP_ERROR,
+    EXCEPTION_PREDEREF_LOAD_ERROR,
+    EXCEPTION_PARROT_USAGE_ERROR,
+    EXCEPTION_PIO_ERROR,
+    EXCEPTION_PARROT_POINTER_ERROR,
+    EXCEPTION_DIV_BY_ZERO,
+    EXCEPTION_PIO_NOT_IMPLEMENTED,
+    EXCEPTION_ALLOCATION_ERROR,
+    EXCEPTION_INTERNAL_PANIC,
+    EXCEPTION_OUT_OF_BOUNDS,
+    EXCEPTION_JIT_ERROR,
+    EXCEPTION_EXEC_ERROR,
+    EXCEPTION_ILL_INHERIT,
+    EXCEPTION_NO_PREV_CS,
+    EXCEPTION_NO_CLASS,
+    EXCEPTION_LEX_NOT_FOUND,
+    EXCEPTION_PAD_NOT_FOUND,
+    EXCEPTION_ATTRIB_NOT_FOUND,
+    EXCEPTION_GLOBAL_NOT_FOUND,
+    EXCEPTION_EXTERNAL_ERROR,
+    EXCEPTION_METHOD_NOT_FOUND,
+    EXCEPTION_VTABLE_NOT_FOUND,
+    EXCEPTION_WRITE_TO_CONSTCLASS,
+    EXCEPTION_NOSPAWN,
+    EXCEPTION_INTERNAL_NOT_IMPLEMENTED,
+    EXCEPTION_ERR_OVERFLOW,
+    EXCEPTION_LOSSY_CONVERSION,
+    EXCEPTION_ROLE_COMPOSITION_METHOD_CONFLICT,
+    EXCEPTION_UNEXPECTED_NULL,
+    EXCEPTION_LIBRARY_ERROR,
+    EXCEPTION_LIBRARY_NOT_LOADED,
+    EXCEPTION_SYNTAX_ERROR,
+    EXCEPTION_MALFORMED_PACKFILE,
 
-        CONTROL_RETURN,
-        CONTROL_OK,
-        CONTROL_BREAK,
-        CONTROL_CONTINUE,
-        CONTROL_ERROR,
-        CONTROL_TAKE,
+    CONTROL_RETURN,
+    CONTROL_OK,
+    CONTROL_BREAK,
+    CONTROL_CONTINUE,
+    CONTROL_ERROR,
+    CONTROL_TAKE,
+    CONTROL_LEAVE,
 
-        CONTROL_LOOP_NEXT,
-        CONTROL_LOOP_LAST,
-        CONTROL_LOOP_REDO
+    CONTROL_LOOP_NEXT,
+    CONTROL_LOOP_LAST,
+    CONTROL_LOOP_REDO
 } exception_type_enum;
 
 /* &end_gen */
@@ -152,10 +153,6 @@ PMC * Parrot_ex_build_exception(PARROT_INTERP,
     ARGIN_NULLOK(STRING *msg))
         __attribute__nonnull__(1);
 
-PARROT_EXPORT
-size_t Parrot_ex_calc_handler_offset(PARROT_INTERP)
-        __attribute__nonnull__(1);
-
 PARROT_EXPORT
 void Parrot_ex_mark_unhandled(PARROT_INTERP, ARGIN(PMC *exception))
         __attribute__nonnull__(1)
@@ -221,47 +218,45 @@ void do_panic(
     unsigned int line);
 
 void Parrot_print_backtrace(void);
-#define ASSERT_ARGS_exit_fatal __attribute__unused__ int _ASSERT_ARGS_CHECK = \
-       PARROT_ASSERT_ARG(format)
-#define ASSERT_ARGS_Parrot_assert __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+#define ASSERT_ARGS_exit_fatal __attribute__unused__ int _ASSERT_ARGS_CHECK = (\
+       PARROT_ASSERT_ARG(format))
+#define ASSERT_ARGS_Parrot_assert __attribute__unused__ int _ASSERT_ARGS_CHECK = (\
        PARROT_ASSERT_ARG(condition_string) \
-    || PARROT_ASSERT_ARG(file)
-#define ASSERT_ARGS_Parrot_confess __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+    , PARROT_ASSERT_ARG(file))
+#define ASSERT_ARGS_Parrot_confess __attribute__unused__ int _ASSERT_ARGS_CHECK = (\
        PARROT_ASSERT_ARG(cond) \
-    || PARROT_ASSERT_ARG(file)
-#define ASSERT_ARGS_Parrot_ex_add_c_handler __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+    , PARROT_ASSERT_ARG(file))
+#define ASSERT_ARGS_Parrot_ex_add_c_handler __attribute__unused__ int _ASSERT_ARGS_CHECK = (\
        PARROT_ASSERT_ARG(interp) \
-    || PARROT_ASSERT_ARG(jp)
-#define ASSERT_ARGS_Parrot_ex_build_exception __attribute__unused__ int _ASSERT_ARGS_CHECK = \
-       PARROT_ASSERT_ARG(interp)
-#define ASSERT_ARGS_Parrot_ex_calc_handler_offset __attribute__unused__ int _ASSERT_ARGS_CHECK = \
-       PARROT_ASSERT_ARG(interp)
-#define ASSERT_ARGS_Parrot_ex_mark_unhandled __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+    , PARROT_ASSERT_ARG(jp))
+#define ASSERT_ARGS_Parrot_ex_build_exception __attribute__unused__ int _ASSERT_ARGS_CHECK = (\
+       PARROT_ASSERT_ARG(interp))
+#define ASSERT_ARGS_Parrot_ex_mark_unhandled __attribute__unused__ int _ASSERT_ARGS_CHECK = (\
        PARROT_ASSERT_ARG(interp) \
-    || PARROT_ASSERT_ARG(exception)
-#define ASSERT_ARGS_Parrot_ex_rethrow_from_c __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+    , PARROT_ASSERT_ARG(exception))
+#define ASSERT_ARGS_Parrot_ex_rethrow_from_c __attribute__unused__ int _ASSERT_ARGS_CHECK = (\
        PARROT_ASSERT_ARG(interp) \
-    || PARROT_ASSERT_ARG(exception)
-#define ASSERT_ARGS_Parrot_ex_rethrow_from_op __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+    , PARROT_ASSERT_ARG(exception))
+#define ASSERT_ARGS_Parrot_ex_rethrow_from_op __attribute__unused__ int _ASSERT_ARGS_CHECK = (\
        PARROT_ASSERT_ARG(interp) \
-    || PARROT_ASSERT_ARG(exception)
-#define ASSERT_ARGS_Parrot_ex_throw_from_c __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+    , PARROT_ASSERT_ARG(exception))
+#define ASSERT_ARGS_Parrot_ex_throw_from_c __attribute__unused__ int _ASSERT_ARGS_CHECK = (\
        PARROT_ASSERT_ARG(interp) \
-    || PARROT_ASSERT_ARG(exception)
-#define ASSERT_ARGS_Parrot_ex_throw_from_c_args __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+    , PARROT_ASSERT_ARG(exception))
+#define ASSERT_ARGS_Parrot_ex_throw_from_c_args __attribute__unused__ int _ASSERT_ARGS_CHECK = (\
        PARROT_ASSERT_ARG(interp) \
-    || PARROT_ASSERT_ARG(format)
-#define ASSERT_ARGS_Parrot_ex_throw_from_op __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+    , PARROT_ASSERT_ARG(format))
+#define ASSERT_ARGS_Parrot_ex_throw_from_op __attribute__unused__ int _ASSERT_ARGS_CHECK = (\
        PARROT_ASSERT_ARG(interp) \
-    || PARROT_ASSERT_ARG(exception)
-#define ASSERT_ARGS_Parrot_ex_throw_from_op_args __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+    , PARROT_ASSERT_ARG(exception))
+#define ASSERT_ARGS_Parrot_ex_throw_from_op_args __attribute__unused__ int _ASSERT_ARGS_CHECK = (\
        PARROT_ASSERT_ARG(interp) \
-    || PARROT_ASSERT_ARG(format)
-#define ASSERT_ARGS_die_from_exception __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+    , PARROT_ASSERT_ARG(format))
+#define ASSERT_ARGS_die_from_exception __attribute__unused__ int _ASSERT_ARGS_CHECK = (\
        PARROT_ASSERT_ARG(interp) \
-    || PARROT_ASSERT_ARG(exception)
-#define ASSERT_ARGS_do_panic __attribute__unused__ int _ASSERT_ARGS_CHECK = 0
-#define ASSERT_ARGS_Parrot_print_backtrace __attribute__unused__ int _ASSERT_ARGS_CHECK = 0
+    , PARROT_ASSERT_ARG(exception))
+#define ASSERT_ARGS_do_panic __attribute__unused__ int _ASSERT_ARGS_CHECK = (0)
+#define ASSERT_ARGS_Parrot_print_backtrace __attribute__unused__ int _ASSERT_ARGS_CHECK = (0)
 /* Don't modify between HEADERIZER BEGIN / HEADERIZER END.  Your changes will be lost. */
 /* HEADERIZER END: src/exceptions.c */
 
@@ -275,22 +270,21 @@ void Parrot_print_backtrace(void);
  * int _ASSERT_ARGS = PARROT_ASSERT_ARG(a) || PARROT_ASSERT_ARG(b) || ...
  */
 #ifdef NDEBUG
-#  define PARROT_ASSERT(x) ((void)0)
+#  define PARROT_ASSERT(x) /*@-noeffect@*/((void)0)/*@=noeffect@*/
 #  define PARROT_ASSERT_ARG(x) (0)
 #  define ASSERT_ARGS(a)
 #else
 #  define PARROT_ASSERT(x) (x) ? ((void)0) : Parrot_confess(#x, __FILE__, __LINE__)
 #  define PARROT_ASSERT_ARG(x) ((x) ? (0) : (Parrot_confess(#x, __FILE__, __LINE__), 0))
 
-#  ifdef _MSC_VER
-#    define ASSERT_ARGS(a)
-#  else
+#  ifdef __GNUC__
 #    define ASSERT_ARGS(a) ASSERT_ARGS_ ## a ;
-#  endif /* _MSC_VER */
+#  else
+#    define ASSERT_ARGS(a)
+#  endif /* __GNUC__ */
 
 #endif /* NDEBUG */
 
-
 #endif /* PARROT_EXCEPTIONS_H_GUARD */
 
 /*
