@@ -1,7 +1,7 @@
 /* parrot.h
  *  Copyright (C) 2001-2009, Parrot Foundation.
  *  SVN Info
- *     $Id: parrot.h 40104 2009-07-15 13:55:49Z NotFound $
+ *     $Id$
  *  Overview:
  *     General header file includes for the parrot interpreter
  *  Data Structure and Algorithms:
@@ -109,11 +109,6 @@ typedef jmp_buf Parrot_jump_buff;
 #define NUM_REGISTERS 32
 #define PARROT_MAGIC 0x13155a1
 
-#define OPCODE_TYPE_PERL 0x5045524c
-#define OPCODE_TYPE_PYTHON 0x5045524b
-#define OPCODE_TYPE_JAVA 4871757
-#define OPCODE_TYPE_MSNET 0x2e4e4554
-
 typedef void STRING_FUNCS;
 typedef struct parrot_interp_t Interp;
 
@@ -264,15 +259,13 @@ typedef struct PackFile_ByteCode PackFile_ByteCode;
 #include "parrot/string.h"
 #include "parrot/string_primitives.h"
 #include "parrot/hash.h"
-#include "parrot/list.h"
 #include "parrot/pmc_freeze.h"
+#include "parrot/list.h"
 #include "parrot/vtable.h"
-#include "parrot/stacks.h"
-#include "parrot/register.h"
+#include "parrot/context.h"
 #include "parrot/exceptions.h"
 #include "parrot/warnings.h"
 #include "parrot/memory.h"
-#include "parrot/pic.h"
 #include "parrot/packfile.h"
 #include "parrot/io.h"
 #include "parrot/op.h"
@@ -296,7 +289,6 @@ typedef struct PackFile_ByteCode PackFile_ByteCode;
 #include "parrot/library.h"
 #include "parrot/global.h"
 #include "parrot/stat.h"
-#include "parrot/slice.h"
 #include "parrot/hll.h"
 #include "parrot/pbcversion.h"
 
