@@ -1,7 +1,7 @@
 /* string.h
  *  Copyright (C) 2001-2003, Parrot Foundation.
  *  SVN Info
- *     $Id: string.h 36833 2009-02-17 20:09:26Z allison $
+ *     $Id$
  *  Overview:
  *     This is the api header for the string subsystem
  *  Data Structure and Algorithms:
@@ -13,10 +13,9 @@
 #ifndef PARROT_STRING_H_GUARD
 #define PARROT_STRING_H_GUARD
 
+#include "parrot/core_types.h"
 #include "parrot/config.h"
 
-struct parrot_string_t;
-
 #ifdef PARROT_IN_CORE
 
 #include "parrot/pobj.h"
