@@ -1,5 +1,5 @@
 # Copyright (C) 2001-2008, Parrot Foundation.
-# $Id: List.pm 39976 2009-07-10 08:20:13Z fperrad $
+# $Id$
 package Parrot::Configure::Step::List;
 use strict;
 use warnings;
@@ -20,8 +20,6 @@ my @steps = qw(
     auto::gcc
     auto::glibc
     auto::backtrace
-    auto::fink
-    auto::macports
     auto::msvc
     auto::attributes
     auto::warnings
@@ -42,8 +40,8 @@ my @steps = qw(
     auto::isreg
     auto::arch
     auto::jit
+    auto::frames
     auto::cpu
-    auto::funcptr
     auto::cgoto
     auto::inline
     auto::gc
