@@ -1,5 +1,5 @@
 # Copyright (C) 2004-2009, Parrot Foundation.
-# $Id: Distribution.pm 39899 2009-07-06 17:48:48Z fperrad $
+# $Id$
 
 =head1 NAME
 
@@ -382,8 +382,6 @@ sub get_c_language_files {
     }
 
     return @c_language_files;
-
-    # RT #50046: pir_source_files() fails to collect PIR .t files.
 }
 
 =item C<is_c_exemption()>
@@ -507,7 +505,6 @@ sub get_perl_exemption_regexp {
         compilers/nqp/
         compilers/ncigen/src/parser/actions.pm
         examples/sdl/
-        examples/languages/abc/src/parser/actions.pm
         examples/languages/squaak/src/parser/actions.pm
         lib/Digest/Perl/
         lib/File/
@@ -568,6 +565,7 @@ sub get_pir_language_files {
     # make sure we're picking up pir files (i.e. look for the shebang line)
     my @pir_files;
     for my $file ( $self->pir_source_files ) {
+        next if $self->is_pir_exemption($file);
         push @pir_files, $file
             if $self->is_pir( $file->path );
     }
@@ -575,6 +573,21 @@ sub get_pir_language_files {
     return @pir_files;
 }
 
+=item C<is_pir_exemption()>
+
+Determines if the given filename is an exemption to being in the PIR source.
+This is to exclude automatically generated PIR-language files Parrot might have.
+
+=cut
+
+{
+    sub is_pir_exemption {
+        my ( $self, $file ) = @_;
+        $file->path =~ m{/ext/};
+    }
+}
+
+
 =item C<is_pir()>
 
 Determines if the given filename is PIR source
