@@ -1,5 +1,5 @@
 # Copyright (C) 2004-2006, Parrot Foundation.
-# $Id: Parrot.pm 40168 2009-07-20 17:39:46Z coke $
+# $Id$
 
 =head1 NAME
 
@@ -60,7 +60,7 @@ sub new {
             'Introduction',
             '',
             $self->new_item( 'Introduction to Parrot', 'docs/intro.pod'),
-            $self->new_item( 'Getting Started', 'docs/book/draft/ch02_getting_started.pod'),
+            $self->new_item( 'Getting Started', 'docs/book/pct/ch02_getting_started.pod'),
             $self->new_item( 'Navigating the Docs', 'docs/parrot.pod'),
             $self->new_item( 'Roles & Responsibilities', 'docs/project/roles_responsibilities.pod'),
             $self->new_item( 'Release History', 'docs/parrothist.pod'),
@@ -80,9 +80,9 @@ sub new {
         $self->new_group(
             'Implementing Languages on Parrot',
             '',
-            $self->new_item( 'Parrot Compiler Tools', 'docs/book/draft/ch04_compiler_tools.pod'),
-            $self->new_item( 'Parrot Grammar Engine', 'docs/book/draft/ch05_pge.pod'),
-            $self->new_item( 'Not Quite Perl', 'docs/book/draft/ch06_nqp.pod'),
+            $self->new_item( 'Parrot Compiler Tools', 'docs/book/pct/ch03_compiler_tools.pod'),
+            $self->new_item( 'Parrot Grammar Engine', 'docs/book/pct/ch04_pge.pod'),
+            $self->new_item( 'Not Quite Perl', 'docs/book/pct/ch05_nqp.pod'),
             $self->new_item( 'Compiler FAQ', 'docs/compiler_faq.pod'),
         ),
         $self->new_group(
@@ -96,28 +96,9 @@ sub new {
             Parrot::Docs::Section::Tools->new,
             $self->new_item( 'Syntax Highlighting for Vim & Emacs', 'editor/README.pod'),
         ),
-        $self->new_group(
-            'Book draft',
-            '',
-            $self->new_item( 'Chapter 1 Introduction', 'docs/book/draft/ch01_introduction.pod'),
-            $self->new_item( 'Chapter 2 Getting Started', 'docs/book/draft/ch02_getting_started.pod'),
-            $self->new_item( 'Chapter 4 Parrot Compiler Tools', 'docs/book/draft/ch04_compiler_tools.pod'),
-            $self->new_item( 'Chapter 5 Parrot Grammar Engine', 'docs/book/draft/ch05_pge.pod'),
-            $self->new_item( 'Chapter 6 Not Quite Perl', 'docs/book/draft/ch06_nqp.pod'),
-            $self->new_item( 'Chapter 7 Dynamic C-level Objects', 'docs/book/draft/ch07_dynpmcs.pod'),
-            $self->new_item( 'Chapter 8 Dynamic Opcodes', 'docs/book/draft/ch08_dynops.pod'),
-            $self->new_item( 'Chapter 10 Instruction Reference', 'docs/book/draft/ch10_opcode_reference.pod'),
-            $self->new_item( 'Chapter 11 Directive Reference', 'docs/book/draft/ch11_directive_reference.pod'),
-            $self->new_item( 'Chapter 12 PIR Operator Reference', 'docs/book/draft/ch12_operator_reference.pod'),
-            $self->new_item( 'Appendix A Glossary', 'docs/book/draft/appa_glossary.pod'),
-            $self->new_item( 'Appendix B Patch Submission', 'docs/book/draft/appb_patch_submission.pod'),
-            $self->new_item( 'Appendix C ', 'docs/book/draft/appc_command_line_options.pod'),
-            $self->new_item( 'Appendix D ', 'docs/book/draft/appd_build_options.pod'),
-            $self->new_item( 'Appendix E ', 'docs/book/draft/appe_source_code.pod'),
-        ),
 
         $self->new_group(
-            'Book PIR',
+            'PIR Book',
             '',
             $self->new_item( 'Chapter 1 Introduction', 'docs/book/pir/ch01_introduction.pod'),
             $self->new_item( 'Chapter 2 Getting Started', 'docs/book/pir/ch02_getting_started.pod'),
@@ -130,6 +111,16 @@ sub new {
             $self->new_item( 'Chapter 9 Exceptions', 'docs/book/pir/ch09_exceptions.pod'),
         ),
 
+        $self->new_group(
+            'PCT Book',
+            '',
+            $self->new_item( 'Chapter 1 Introduction', 'docs/book/pct/ch01_introduction.pod'),
+            $self->new_item( 'Chapter 2 Getting Started', 'docs/book/pct/ch02_getting_started.pod'),
+            $self->new_item( 'Chapter 3 Compiler Tools', 'docs/book/pct/ch03_compiler_tools.pod'),
+            $self->new_item( 'Chapter 4 Grammar Engine', 'docs/book/pct/ch04_pge.pod'),
+            $self->new_item( 'Chapter 5 Grammar Actions', 'docs/book/pct/ch05_nqp.pod'),
+        ),
+
 #        Parrot::Docs::Section::C->new,
 #        Parrot::Docs::Section::IMCC->new,
 #        Parrot::Docs::Section::Perl->new,
