@@ -1,5 +1,5 @@
 # Copyright (C) 2004-2008, Parrot Foundation.
-# $Id: Method.pm 40100 2009-07-15 13:15:25Z bacek $
+# $Id$
 package Parrot::Pmc2c::Method;
 use strict;
 use warnings;
@@ -9,6 +9,22 @@ use constant NON_VTABLE   => 'NON_VTABLE';
 use constant MULTI        => 'MULTI';
 use Parrot::Pmc2c::UtilFunctions qw( args_from_parameter_list passable_args_from_parameter_list );
 
+=head1 NAME
+
+Parrot::Pmc2c::Method
+
+=head1 DESCRIPTION
+
+Functions used in transformation of PMCs to C code.
+
+=head1 METHODS
+
+=head2 C<new()>
+
+Parrot::Pmc2c::Method constructor.
+
+=cut
+
 sub new {
     my ( $class, $self_hash ) = @_;
     my $self = {
@@ -89,7 +105,7 @@ sub pmc_unused {
     return $self->{pmc_unused};
 }
 
-=head1 C<trans($type)>
+=head2 C<trans($type)>
 
 Used in C<signature()> to normalize argument types.
 
@@ -111,7 +127,7 @@ sub trans {
     return '?';
 }
 
-=head1 C<signature()>
+=head2 C<signature()>
 
 Returns the method signature for the methods $parameters
 
@@ -149,6 +165,51 @@ sub signature {
     return ( $return_prefix, $method_suffix, $args, $sig, $return_type_char, $null_return );
 }
 
+=head2 C<pcc_signature()>
+
+Returns a PCC-style method signature for the method's parameters, as well as
+some additional information useful in building a call to that method.
+
+=cut
+
+sub pcc_signature {
+    my ($self) = @_;
+
+    my $args             = passable_args_from_parameter_list( $self->parameters );
+    my ($types, $vars)   = args_from_parameter_list( $self->parameters );
+    my $return_type      = $self->return_type;
+    my $return_type_char = $self->trans($return_type);
+    my $sig              = join ('', map { $self->trans($_) } @{$types}) .
+                           '->';
+
+    my $result_decl    = '';
+    my $return_stmt    = '';
+
+    if ( $return_type eq 'void' ) {
+        $return_stmt = "return ($return_type) NULL;" if $return_type_char =~ /P|I|S|V/;
+        $return_stmt = 'return (FLOATVAL) 0;'        if $return_type_char =~ /N/;
+        $return_stmt = 'return;'                     if $return_type_char =~ /v/;
+    }
+    else {
+        $result_decl = "$return_type result;";
+        $args .= ', &result';
+        $sig .= $return_type_char;
+        $return_stmt = "return ($return_type) result;";
+    }
+
+    return ( $sig, $args, $result_decl, $return_stmt );
+}
+
+=head1 SEE ALSO
+
+    lib/Parrot/Pmc2c/PMC/RO.pm
+    lib/Parrot/Pmc2c/PMCEmitter.pm
+    lib/Parrot/Pmc2c/VTable.pm
+    lib/Parrot/Pmc2c/PMC.pm
+    lib/Parrot/Pmc2c/Parser.pm
+
+=cut
+
 1;
 
 # Local Variables:
