@@ -1,13 +1,23 @@
 package Parrot::Pmc2c::PMC::Object;
 
 # Copyright (C) 2007-2008, Parrot Foundation.
-# $Id: Object.pm 36833 2009-02-17 20:09:26Z allison $
+# $Id$
 
 use base 'Parrot::Pmc2c::PMC';
 use strict;
 use warnings;
 
-=head1 C<body($method, $line, $out_name)>
+=head1 NAME
+
+Parrot::Pmc2c::PMC::Object
+
+=head1 DESCRIPTION
+
+PMC to C Methods
+
+=head1 METHODS
+
+=head2 C<body($method, $line, $out_name)>
 
 Returns the C code for the method body.
 
@@ -34,6 +44,8 @@ sub pre_method_gen {
 
         my ( $return_prefix, $ret_suffix, $args, $sig, $return_type_char, $null_return ) =
             $new_default_method->signature;
+        my ( $pcc_sig, $pcc_args, $pcc_result_decl, $pcc_return_stmt ) =
+            $new_default_method->pcc_signature;
         my $void_return  = $return_type_char eq 'v' ? 'return;'    : '';
         my $return       = $return_type_char eq 'v' ? ''           : $return_prefix;
         my $superargs    = $args;
@@ -53,8 +65,9 @@ sub pre_method_gen {
 
         PMC * const meth = Parrot_oo_find_vtable_override_for_class(interp, cur_class, meth_name);
         if (!PMC_IS_NULL(meth)) {
-            ${return}Parrot_run_meth_fromc_args$ret_suffix(interp, meth, pmc, meth_name, "$sig"$args);
-            $void_return
+            $pcc_result_decl
+            Parrot_pcc_invoke_sub_from_c_args(interp, meth, "Pi$pcc_sig", pmc$pcc_args);
+            $pcc_return_stmt
         }
         /* method name is $vt_method_name */
 EOC
