@@ -1,7 +1,15 @@
 # Copyright (C) 2007, Parrot Foundation.
-# $Id: ParrotClass.pm 36833 2009-02-17 20:09:26Z allison $
+# $Id$
 
-=head1 Parrot::Pmc2c::ParrotClass Instance Methods
+=head1 NAME
+
+Parrot::Pmc2c::ParrotClass
+
+=head1 DESCRIPTION
+
+Instance Methods
+
+=head1 METHODS
 
 =over 4
 
@@ -19,6 +27,8 @@ Mixes in delegate.pmc methods for all unimplmented methods except
 @dont_delegate which should fall through to the default.pmc
 implementation.
 
+=back
+
 =cut
 
 our @dont_delegate = qw(
@@ -43,7 +53,6 @@ our @dont_delegate = qw(
     getprops
     is_same
     morph
-    nextkey_keyed_int
     set_integer_keyed_int
     set_number_keyed_int
     set_pmc_keyed_int
