@@ -1,5 +1,5 @@
 # Copyright (C) 2007-2009, Parrot Foundation.
-# $Id: PMCEmitter.pm 40100 2009-07-15 13:15:25Z bacek $
+# $Id$
 
 =head1 NAME
 
@@ -50,7 +50,7 @@ sub generate {
     $emitter->write_to_file;
 
     $emitter = $self->{emitter} =
-        Parrot::Pmc2c::Emitter->new( $self->filename(".h") );
+        Parrot::Pmc2c::Emitter->new( $self->filename(".h", $self->is_dynamic) );
 
     $self->generate_h_file;
     $emitter->write_to_file;
@@ -76,7 +76,8 @@ sub generate_c_file {
     $self->gen_includes;
 
     # The PCC code needs Continuation-related macros from these headers.
-    $c->emit("#include \"pmc_continuation.h\"\n");
+    $c->emit("#include \"pmc/pmc_continuation.h\"\n");
+    $c->emit("#include \"pmc/pmc_callcontext.h\"\n");
 
     $c->emit( $self->preamble );
 
@@ -90,7 +91,7 @@ sub generate_c_file {
         $ro->gen_methods;
     }
 
-    $c->emit("#include \"pmc_default.h\"\n");
+    $c->emit("#include \"pmc/pmc_default.h\"\n");
 
     $c->emit( $self->update_vtable_func );
     $c->emit( $self->get_vtable_func );
@@ -275,8 +276,6 @@ my %calltype = (
     "void"     => "v",
     "void*"    => "b",
     "void**"   => "B",
-
-    #"BIGNUM*" => "???" # RT#43731
 );
 
 sub proto {
@@ -292,13 +291,9 @@ sub proto {
     # type method(interp, self, parameters...)
     my $ret = $calltype{ $type or "void" }
         . "JO"
-        . join( '', map { $calltype{$_} or "?" } split( /,/, $parameters ) );
-
-    # RT #43733
-    # scan src/call_list.txt if the generated signature is available
-
-    # RT #43735 report errors for "?"
-    # --leo
+        . join( '',
+            map { $calltype{$_} or die "Unknown signature type '$_'" }
+            split( /,/, $parameters ) );
 
     return $ret;
 }
@@ -421,7 +416,6 @@ sub vtable_flags {
     my ($self) = @_;
 
     my $vtbl_flag = 0;
-    $vtbl_flag .= '|VTABLE_PMC_NEEDS_EXT'     if $self->flag('need_ext');
     $vtbl_flag .= '|VTABLE_PMC_IS_SINGLETON'  if $self->flag('singleton');
     $vtbl_flag .= '|VTABLE_IS_SHARED_FLAG'    if $self->flag('is_shared');
     $vtbl_flag .= '|VTABLE_IS_READONLY_FLAG'  if $self->flag('is_ro');
@@ -464,7 +458,8 @@ sub vtable_decl {
         NULL,       /* mro */
         NULL,       /* attribute_defs */
         NULL,       /* ro_variant_vtable */
-        $methlist
+        $methlist,
+	0           /* attr size */
     };
 ENDOFCODE
     return $cout;
@@ -581,14 +576,6 @@ EOC
     $cout .= "\";\n";
 
     my $const = ( $self->{flags}{dynpmc} ) ? " " : " const ";
-    if ( @$multi_funcs ) {
-        $cout .= $multi_strings . <<"EOC";
-
-   $const multi_func_list _temp_multi_func_list[] = {
-        $multi_list
-    };
-EOC
-    }
 
     my $flags = $self->vtable_flags;
     $cout .= <<"EOC";
@@ -640,6 +627,7 @@ EOC
             vt_${k}                 = Parrot_${classname}_${k}_get_vtable(interp);
             vt_${k}->base_type      = $enum_name;
             vt_${k}->flags          = $k_flags;
+
             vt_${k}->attribute_defs = attr_defs;
 
             vt_${k}->base_type           = entry;
@@ -666,12 +654,12 @@ EOC
 
         {
             /* Register this PMC as a HLL mapping */
-            const INTVAL pmc_id = Parrot_get_HLL_id( interp, CONST_STRING_GEN(interp, "$hll"));
-            if (pmc_id > 0) {
+            const INTVAL hll_id = Parrot_get_HLL_id( interp, CONST_STRING_GEN(interp, "$hll"));
+            if (hll_id > 0) {
 EOC
         foreach my $maps ( sort keys %{ $self->{flags}{maps} } ) {
             $cout .= <<"EOC";
-                Parrot_register_HLL_type( interp, pmc_id, enum_class_$maps, entry);
+                Parrot_register_HLL_type( interp, hll_id, enum_class_$maps, entry);
 EOC
         }
         $cout .= <<"EOC";
@@ -728,7 +716,11 @@ EOC
 
 
     if ( @$multi_funcs ) {
-        $cout .= <<"EOC";
+        $cout .= $multi_strings . <<"EOC";
+
+            $const multi_func_list _temp_multi_func_list[] = {
+                $multi_list
+            };
 #define N_MULTI_LIST (sizeof(_temp_multi_func_list)/sizeof(_temp_multi_func_list[0]))
             Parrot_mmd_add_multi_list_from_c_args(interp,
                 _temp_multi_func_list, N_MULTI_LIST);
@@ -761,6 +753,22 @@ sub update_vtable_func {
     my $classname = $self->name;
     my $export = $self->is_dynamic ? 'PARROT_DYNEXT_EXPORT ' : 'PARROT_EXPORT';
 
+    # Sets the attr_size field:
+    # If the auto_attrs flag is set, use the current data,
+    # else check if this PMC has init or init_pmc vtable functions,
+    # setting it to 0 in that case, and keeping the value from the
+    # parent otherwise.
+    my $set_attr_size = '';
+    if ( @{$self->attributes} && $self->{flags}{auto_attrs} ) {
+        $set_attr_size .= "sizeof(Parrot_${classname}_attributes)";
+    }
+    else {
+        $set_attr_size .= "0" if exists($self->{has_method}{init}) ||
+                                 exists($self->{has_method}{init_pmc});
+    }
+    $set_attr_size =     "    vt->attr_size = " . $set_attr_size . ";\n"
+        if $set_attr_size ne '';
+
     my $vtable_updates = '';
     for my $name ( @{ $self->vtable->names } ) {
         if (exists $self->{has_method}{$name}) {
@@ -768,6 +776,8 @@ sub update_vtable_func {
         }
     }
 
+    $vtable_updates .= $set_attr_size;
+
     $cout .= <<"EOC";
 
 $export
@@ -793,6 +803,8 @@ EOC
         }
     }
 
+    $vtable_updates .= $set_attr_size;
+
     $cout .= <<"EOC";
 
 $export
@@ -1095,7 +1107,7 @@ sub gen_defaul_case_wrapping {
     elsif ($letter eq 'P') {
         return (
             'PPP->P',
-            'PMC *retval;',
+            'PMC *retval = PMCNULL;',
             ", &retval",
             "return retval;",
         );
