@@ -1,5 +1,5 @@
-# Copyright (C) 2004-2008, The Perl Foundation.
-# $Id: /mirror/trunk/lib/Parrot/Pmc2c/VTable.pm 34589 2008-12-29T06:55:43.954267Z petdance  $
+# Copyright (C) 2004-2008, Parrot Foundation.
+# $Id$
 package Parrot::Pmc2c::VTable;
 use strict;
 use warnings;
@@ -15,7 +15,7 @@ sub new {
     my $self = {};
     bless $self, $class;
     $self->build($filename) if $filename;
-    $self;
+    return $self;
 }
 
 sub build {
@@ -47,6 +47,8 @@ sub build {
     $self->{'has_method'} = \%method_lookup;
     $self->{'methods'}    = \@methods;
     $self->{'names'}      = \@method_names;
+
+    return;
 }
 
 sub right_type {
