@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2001-2009, Parrot Foundation.
-$Id: hash.c 40107 2009-07-15 15:06:53Z NotFound $
+$Id$
 
 =head1 NAME
 
@@ -84,14 +84,6 @@ static size_t key_hash_pointer(SHIM_INTERP,
     size_t seed)
         __attribute__nonnull__(2);
 
-PARROT_WARN_UNUSED_RESULT
-static size_t key_hash_STRING(PARROT_INTERP,
-    ARGMOD(STRING *s),
-    SHIM(size_t seed))
-        __attribute__nonnull__(1)
-        __attribute__nonnull__(2)
-        FUNC_MODIFIES(*s);
-
 static void parrot_mark_hash_both(PARROT_INTERP, ARGIN(Hash *hash))
         __attribute__nonnull__(1)
         __attribute__nonnull__(2);
@@ -104,53 +96,33 @@ static void parrot_mark_hash_values(PARROT_INTERP, ARGIN(Hash *hash))
         __attribute__nonnull__(1)
         __attribute__nonnull__(2);
 
-PARROT_WARN_UNUSED_RESULT
-PARROT_PURE_FUNCTION
-static int pointer_compare(SHIM_INTERP,
-    ARGIN_NULLOK(const void *a),
-    ARGIN_NULLOK(const void *b));
-
-PARROT_WARN_UNUSED_RESULT
-static int STRING_compare(PARROT_INTERP,
-    ARGIN(const void *search_key),
-    ARGIN_NULLOK(const void *bucket_key))
-        __attribute__nonnull__(1)
-        __attribute__nonnull__(2);
-
-#define ASSERT_ARGS_cstring_compare __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+#define ASSERT_ARGS_cstring_compare __attribute__unused__ int _ASSERT_ARGS_CHECK = (\
        PARROT_ASSERT_ARG(a) \
-    || PARROT_ASSERT_ARG(b)
-#define ASSERT_ARGS_expand_hash __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+    , PARROT_ASSERT_ARG(b))
+#define ASSERT_ARGS_expand_hash __attribute__unused__ int _ASSERT_ARGS_CHECK = (\
        PARROT_ASSERT_ARG(interp) \
-    || PARROT_ASSERT_ARG(hash)
-#define ASSERT_ARGS_hash_freeze __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+    , PARROT_ASSERT_ARG(hash))
+#define ASSERT_ARGS_hash_freeze __attribute__unused__ int _ASSERT_ARGS_CHECK = (\
        PARROT_ASSERT_ARG(interp) \
-    || PARROT_ASSERT_ARG(hash) \
-    || PARROT_ASSERT_ARG(info)
-#define ASSERT_ARGS_hash_thaw __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+    , PARROT_ASSERT_ARG(hash) \
+    , PARROT_ASSERT_ARG(info))
+#define ASSERT_ARGS_hash_thaw __attribute__unused__ int _ASSERT_ARGS_CHECK = (\
        PARROT_ASSERT_ARG(interp) \
-    || PARROT_ASSERT_ARG(hash) \
-    || PARROT_ASSERT_ARG(info)
-#define ASSERT_ARGS_key_hash_cstring __attribute__unused__ int _ASSERT_ARGS_CHECK = \
-       PARROT_ASSERT_ARG(value)
-#define ASSERT_ARGS_key_hash_pointer __attribute__unused__ int _ASSERT_ARGS_CHECK = \
-       PARROT_ASSERT_ARG(value)
-#define ASSERT_ARGS_key_hash_STRING __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+    , PARROT_ASSERT_ARG(hash) \
+    , PARROT_ASSERT_ARG(info))
+#define ASSERT_ARGS_key_hash_cstring __attribute__unused__ int _ASSERT_ARGS_CHECK = (\
+       PARROT_ASSERT_ARG(value))
+#define ASSERT_ARGS_key_hash_pointer __attribute__unused__ int _ASSERT_ARGS_CHECK = (\
+       PARROT_ASSERT_ARG(value))
+#define ASSERT_ARGS_parrot_mark_hash_both __attribute__unused__ int _ASSERT_ARGS_CHECK = (\
        PARROT_ASSERT_ARG(interp) \
-    || PARROT_ASSERT_ARG(s)
-#define ASSERT_ARGS_parrot_mark_hash_both __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+    , PARROT_ASSERT_ARG(hash))
+#define ASSERT_ARGS_parrot_mark_hash_keys __attribute__unused__ int _ASSERT_ARGS_CHECK = (\
        PARROT_ASSERT_ARG(interp) \
-    || PARROT_ASSERT_ARG(hash)
-#define ASSERT_ARGS_parrot_mark_hash_keys __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+    , PARROT_ASSERT_ARG(hash))
+#define ASSERT_ARGS_parrot_mark_hash_values __attribute__unused__ int _ASSERT_ARGS_CHECK = (\
        PARROT_ASSERT_ARG(interp) \
-    || PARROT_ASSERT_ARG(hash)
-#define ASSERT_ARGS_parrot_mark_hash_values __attribute__unused__ int _ASSERT_ARGS_CHECK = \
-       PARROT_ASSERT_ARG(interp) \
-    || PARROT_ASSERT_ARG(hash)
-#define ASSERT_ARGS_pointer_compare __attribute__unused__ int _ASSERT_ARGS_CHECK = 0
-#define ASSERT_ARGS_STRING_compare __attribute__unused__ int _ASSERT_ARGS_CHECK = \
-       PARROT_ASSERT_ARG(interp) \
-    || PARROT_ASSERT_ARG(search_key)
+    , PARROT_ASSERT_ARG(hash))
 /* Don't modify between HEADERIZER BEGIN / HEADERIZER END.  Your changes will be lost. */
 /* HEADERIZER END: static */
 
@@ -158,7 +130,7 @@ static int STRING_compare(PARROT_INTERP,
 
 /*
 
-=item C<static size_t key_hash_STRING(PARROT_INTERP, STRING *s, size_t seed)>
+=item C<size_t key_hash_STRING(PARROT_INTERP, STRING *s, size_t seed)>
 
 Returns the hashed value of the key C<value>.  See also string.c.
 
@@ -168,7 +140,7 @@ Returns the hashed value of the key C<value>.  See also string.c.
 
 
 PARROT_WARN_UNUSED_RESULT
-static size_t
+size_t
 key_hash_STRING(PARROT_INTERP, ARGMOD(STRING *s), SHIM(size_t seed))
 {
     ASSERT_ARGS(key_hash_STRING)
@@ -176,14 +148,14 @@ key_hash_STRING(PARROT_INTERP, ARGMOD(STRING *s), SHIM(size_t seed))
     if (s->hashval)
         return s->hashval;
 
-   return Parrot_str_to_hashval(interp, s);
+    return Parrot_str_to_hashval(interp, s);
 }
 
 
 /*
 
-=item C<static int STRING_compare(PARROT_INTERP, const void *search_key, const
-void *bucket_key)>
+=item C<int STRING_compare(PARROT_INTERP, const void *search_key, const void
+*bucket_key)>
 
 Compares the two strings, returning 0 if they are identical.
 
@@ -192,7 +164,7 @@ Compares the two strings, returning 0 if they are identical.
 */
 
 PARROT_WARN_UNUSED_RESULT
-static int
+int
 STRING_compare(PARROT_INTERP, ARGIN(const void *search_key), ARGIN_NULLOK(const void *bucket_key))
 {
     ASSERT_ARGS(STRING_compare)
@@ -206,7 +178,7 @@ STRING_compare(PARROT_INTERP, ARGIN(const void *search_key), ARGIN_NULLOK(const
         return 1;
 
     /* COWed strings */
-    if (s1->strstart == s2->strstart && s1->bufused == s2->bufused)
+    if (Buffer_bufstart(s1) == Buffer_bufstart(s2) && s1->bufused == s2->bufused)
         return 0;
 
     return CHARSET_COMPARE(interp, s1, s2);
@@ -215,7 +187,7 @@ STRING_compare(PARROT_INTERP, ARGIN(const void *search_key), ARGIN_NULLOK(const
 
 /*
 
-=item C<static int pointer_compare(PARROT_INTERP, const void *a, const void *b)>
+=item C<int pointer_compare(PARROT_INTERP, const void *a, const void *b)>
 
 Compares the two pointers, returning 0 if they are identical
 
@@ -225,7 +197,7 @@ Compares the two pointers, returning 0 if they are identical
 
 PARROT_WARN_UNUSED_RESULT
 PARROT_PURE_FUNCTION
-static int
+int
 pointer_compare(SHIM_INTERP, ARGIN_NULLOK(const void *a), ARGIN_NULLOK(const void *b))
 {
     ASSERT_ARGS(pointer_compare)
@@ -309,6 +281,54 @@ cstring_compare(SHIM_INTERP, ARGIN(const char *a), ARGIN(const char *b))
 }
 
 
+/*
+
+=item C<size_t key_hash_PMC(PARROT_INTERP, PMC *value, size_t seed)>
+
+Returns a hashed value for an PMC key (passed as a void pointer, sadly).
+
+=cut
+
+*/
+
+PARROT_WARN_UNUSED_RESULT
+PARROT_PURE_FUNCTION
+size_t
+key_hash_PMC(PARROT_INTERP, ARGIN(PMC *value), SHIM(size_t seed))
+{
+    ASSERT_ARGS(key_hash_PMC)
+    return VTABLE_hashvalue(interp, value);
+}
+
+/*
+
+=item C<int PMC_compare(PARROT_INTERP, PMC *a, PMC *b)>
+
+Compares two PMC for equality, returning 0 if the first is equal to second.
+Uses void pointers to store the PMC, sadly.
+
+=cut
+
+*/
+
+PARROT_WARN_UNUSED_RESULT
+PARROT_PURE_FUNCTION
+int
+PMC_compare(PARROT_INTERP, ARGIN(PMC *a), ARGIN_NULLOK(PMC *b))
+{
+    ASSERT_ARGS(PMC_compare)
+
+    /* If pointers are same - PMCs are same */
+    if (a == b)
+        return 0;
+
+    /* PMCs of different types are differ */
+    if (a->vtable->base_type != b->vtable->base_type)
+        return 1;
+
+    return !VTABLE_is_equal(interp, a, b);
+}
+
 /*
 
 =item C<size_t key_hash_int(PARROT_INTERP, const void *value, size_t seed)>
@@ -535,7 +555,6 @@ static void
 hash_thaw(PARROT_INTERP, ARGMOD(Hash *hash), ARGMOD(visit_info *info))
 {
     ASSERT_ARGS(hash_thaw)
-    IMAGE_IO * const io         = info->image_io;
 
     /* during thaw, info->extra is the key/value count */
     const size_t     num_entries = (size_t) hash->entries;
@@ -547,43 +566,41 @@ hash_thaw(PARROT_INTERP, ARGMOD(Hash *hash), ARGMOD(visit_info *info))
         HashBucket *b;
 
         switch (hash->key_type) {
-            case Hash_key_type_STRING:
-                {
-                    STRING * const s_key = VTABLE_shift_string(interp, io);
-                    b = parrot_hash_put(interp, hash, s_key, NULL);
-                }
-                break;
-            case Hash_key_type_int:
-                {
-                    const INTVAL i_key = VTABLE_shift_integer(interp, io);
-                    b = parrot_hash_put(interp, hash, (void*)i_key, NULL);
-                }
-                break;
-            default:
-                Parrot_ex_throw_from_c_args(interp, NULL, 1,
+          case Hash_key_type_STRING:
+            {
+                STRING * const s_key = VTABLE_shift_string(interp, info);
+                b = parrot_hash_put(interp, hash, s_key, NULL);
+            }
+            break;
+          case Hash_key_type_int:
+            {
+                const INTVAL i_key = VTABLE_shift_integer(interp, info);
+                b = parrot_hash_put(interp, hash, (void*)i_key, NULL);
+            }
+            break;
+          default:
+            Parrot_ex_throw_from_c_args(interp, NULL, 1,
                     "unimplemented key type");
-                break;
+            break;
         }
 
         switch (hash->entry_type) {
-            case enum_hash_pmc:
-                {
-                    /* this looks awful, but it avoids type-punning warnings */
-                    void **ptr     = &b->value;
-                    info->thaw_ptr = (PMC **)ptr;
-                    (info->visit_pmc_now)(interp, NULL, info);
-                    break;
-                }
-            case enum_hash_int:
-                {
-                    const INTVAL i = VTABLE_shift_integer(interp, io);
-                    b->value       = (void *)i;
-                    break;
-                }
-            default:
-                Parrot_ex_throw_from_c_args(interp, NULL, 1,
-                    "unimplemented value type");
+          case enum_hash_pmc:
+            {
+                PMC *p   = VTABLE_shift_pmc(interp, info);
+                b->value = (void *)p;
                 break;
+            }
+          case enum_hash_int:
+            {
+                const INTVAL i = VTABLE_shift_integer(interp, info);
+                b->value       = (void *)i;
+                break;
+            }
+          default:
+            Parrot_ex_throw_from_c_args(interp, NULL, 1,
+                    "unimplemented value type");
+            break;
         }
     }
 }
@@ -609,36 +626,35 @@ static void
 hash_freeze(PARROT_INTERP, ARGIN(const Hash * const hash), ARGMOD(visit_info *info))
 {
     ASSERT_ARGS(hash_freeze)
-    IMAGE_IO * const io = info->image_io;
     size_t           i;
 
     for (i = 0; i < hash->entries; i++) {
         HashBucket * const b = hash->bs+i;
 
         switch (hash->key_type) {
-            case Hash_key_type_STRING:
-                VTABLE_push_string(interp, io, (STRING *)b->key);
-                break;
-            case Hash_key_type_int:
-                VTABLE_push_integer(interp, io, (INTVAL)b->key);
-                break;
-            default:
-                Parrot_ex_throw_from_c_args(interp, NULL, 1,
+          case Hash_key_type_STRING:
+            VTABLE_push_string(interp, info, (STRING *)b->key);
+            break;
+          case Hash_key_type_int:
+            VTABLE_push_integer(interp, info, (INTVAL)b->key);
+            break;
+          default:
+            Parrot_ex_throw_from_c_args(interp, NULL, 1,
                     "unimplemented key type");
-                break;
+            break;
         }
 
         switch (hash->entry_type) {
-            case enum_hash_pmc:
-                (info->visit_pmc_now)(interp, (PMC *)b->value, info);
-                break;
-            case enum_hash_int:
-                VTABLE_push_integer(interp, io, (INTVAL)b->value);
-                break;
-            default:
-                Parrot_ex_throw_from_c_args(interp, NULL, 1,
+          case enum_hash_pmc:
+            VTABLE_push_pmc(interp, info, (PMC *)b->value);
+            break;
+          case enum_hash_int:
+            VTABLE_push_integer(interp, info, (INTVAL)b->value);
+            break;
+          default:
+            Parrot_ex_throw_from_c_args(interp, NULL, 1,
                     "unimplemented value type");
-                break;
+            break;
         }
     }
 }
@@ -663,17 +679,15 @@ parrot_hash_visit(PARROT_INTERP, ARGMOD(Hash *hash), ARGMOD(void *pinfo))
     ASSERT_ARGS(parrot_hash_visit)
     visit_info* const info = (visit_info*) pinfo;
 
-    switch (info->what) {
-        case VISIT_THAW_NORMAL:
-        case VISIT_THAW_CONSTANTS:
-            hash_thaw(interp, hash, info);
-            break;
-        case VISIT_FREEZE_NORMAL:
-        case VISIT_FREEZE_AT_DESTRUCT:
-            hash_freeze(interp, hash, info);
-            break;
-        default:
-            Parrot_ex_throw_from_c_args(interp, NULL, 1,
+    switch (VTABLE_get_integer(interp, info)) {
+      case VISIT_THAW_NORMAL:
+        hash_thaw(interp, hash, info);
+        break;
+      case VISIT_FREEZE_NORMAL:
+        hash_freeze(interp, hash, info);
+        break;
+      default:
+        Parrot_ex_throw_from_c_args(interp, NULL, 1,
                 "unimplemented visit mode");
     }
 }
@@ -769,7 +783,7 @@ expand_hash(PARROT_INTERP, ARGMOD(Hash *hash))
     hash->mask = new_size - 1;
 
     /* clear freshly allocated bucket index */
-    memset(new_bi + old_size, 0, sizeof (HashBucket *) * (new_size - old_size));
+    memset(new_bi + old_size, 0, sizeof (HashBucket *) * old_size);
 
     /*
      * reloc pointers - this part would be also needed, if we
@@ -841,26 +855,6 @@ parrot_new_hash(PARROT_INTERP)
 }
 
 
-/*
-
-=item C<void parrot_new_pmc_hash(PARROT_INTERP, PMC *container)>
-
-Creates a new Parrot STRING hash in C<container>.
-
-=cut
-
-*/
-
-PARROT_EXPORT
-void
-parrot_new_pmc_hash(PARROT_INTERP, ARGOUT(PMC *container))
-{
-    ASSERT_ARGS(parrot_new_pmc_hash)
-    Hash * const hash = parrot_new_hash(interp);
-    VTABLE_set_pointer(interp, container, hash);
-}
-
-
 /*
 
 =item C<Hash* parrot_new_cstring_hash(PARROT_INTERP)>
@@ -1010,7 +1004,7 @@ parrot_create_hash(PARROT_INTERP, PARROT_DATA_TYPE val_type, Hash_key_type hkey_
 =item C<void parrot_hash_destroy(PARROT_INTERP, Hash *hash)>
 
 Frees the memory allocated to the specified hash and its bucket store.  Used by
-Parrot_chash_destroy.
+parrot_chash_destroy.
 
 =cut
 
@@ -1302,18 +1296,19 @@ parrot_hash_put(PARROT_INTERP, ARGMOD(Hash *hash),
     const UINTVAL hashval = (hash->hash_val)(interp, key, hash->seed);
     HashBucket   *bucket  = hash->bi[hashval & hash->mask];
 
-    /* Very complex assert that we'll not put non-constant stuff into constant hash */
-    PARROT_ASSERT(
-        PMC_IS_NULL(hash->container)
-        || !(PObj_constant_TEST(hash->container))
-        || (
-            (
-                !(hash->key_type == Hash_key_type_STRING)
-                || PObj_constant_TEST((PObj *)key))
-            && (
-                !((hash->entry_type == enum_type_PMC) || (hash->entry_type == enum_type_STRING))
-                || PObj_constant_TEST((PObj *)value)))
-        || !"Use non-constant key or value in constant hash");
+    /* When the hash is constant, check that the key and value are also
+     * constant. */
+    if (!PMC_IS_NULL(hash->container)
+            && PObj_constant_TEST(hash->container)) {
+        if (hash->key_type == Hash_key_type_STRING
+                && !PObj_constant_TEST((PObj *)key))
+            Parrot_ex_throw_from_c_args(interp, NULL, EXCEPTION_INVALID_OPERATION,
+                "Used non-constant key in constant hash.");
+        if (((hash->entry_type == enum_type_PMC) || (hash->entry_type == enum_type_STRING))
+                && !PObj_constant_TEST((PObj *)value))
+            Parrot_ex_throw_from_c_args(interp, NULL, EXCEPTION_INVALID_OPERATION,
+                "Used non-constant value in constant hash.");
+    }
 
     while (bucket) {
         /* store hash_val or not */
@@ -1322,19 +1317,9 @@ parrot_hash_put(PARROT_INTERP, ARGMOD(Hash *hash),
         bucket = bucket->next;
     }
 
-    if (bucket) {
-        if (hash->entry_type == enum_type_PMC && hash->container) {
-            GC_WRITE_BARRIER_KEY(interp, hash->container,
-                    (PMC *)bucket->value, bucket->key, (PMC *)value, key);
-        }
-
+    if (bucket)
         bucket->value = value;
-    }
     else {
-        if (hash->entry_type == enum_type_PMC && hash->container) {
-            GC_WRITE_BARRIER_KEY(interp, hash->container,
-                    NULL, NULL, (PMC *)value, key);
-        }
 
         bucket = hash->free_list;
 
@@ -1419,36 +1404,662 @@ parrot_hash_clone(PARROT_INTERP, ARGIN(const Hash *hash), ARGOUT(Hash *dest))
         void * const  key = b->key;
 
         switch (hash->entry_type) {
-            case enum_type_undef:
-            case enum_type_ptr:
-            case enum_type_INTVAL:
-                valtmp = (void *)b->value;
-                break;
+          case enum_type_undef:
+          case enum_type_ptr:
+          case enum_type_INTVAL:
+            valtmp = (void *)b->value;
+            break;
 
-            case enum_type_STRING:
-                valtmp = (void *)Parrot_str_copy(interp, (STRING *)b->value);
-                break;
+          case enum_type_STRING:
+            valtmp = (void *)Parrot_str_copy(interp, (STRING *)b->value);
+            break;
 
-            case enum_type_PMC:
-                if (PMC_IS_NULL((PMC *)b->value))
-                    valtmp = (void *)PMCNULL;
-                else
-                    valtmp = (void *)VTABLE_clone(interp, (PMC*)b->value);
-                break;
+          case enum_type_PMC:
+            if (PMC_IS_NULL((PMC *)b->value))
+                valtmp = (void *)PMCNULL;
+            else
+                valtmp = (void *)VTABLE_clone(interp, (PMC*)b->value);
+            break;
 
-            default:
-                valtmp = NULL; /* avoid warning */
-                Parrot_ex_throw_from_c_args(interp, NULL, -1,
+          default:
+            valtmp = NULL; /* avoid warning */
+            Parrot_ex_throw_from_c_args(interp, NULL, -1,
                     "hash corruption: type = %d\n", hash->entry_type);
         };
 
-        if (key)
+        if (key){
             parrot_hash_put(interp, dest, key, valtmp);
+        }
     }
 }
 
 /*
 
+=item C<PMC* get_integer_pmc(PARROT_INTERP, INTVAL value)>
+
+Lookup the PMC type which is used for storing native integers.
+
+=cut
+
+*/
+
+PARROT_CANNOT_RETURN_NULL
+PMC*
+get_integer_pmc(PARROT_INTERP, INTVAL value)
+{
+    ASSERT_ARGS(get_integer_pmc)
+    PMC * const ret = pmc_new(interp, Parrot_get_ctx_HLL_type(interp, enum_class_Integer));
+    VTABLE_set_integer_native(interp, ret, value);
+    return ret;
+}
+
+
+/*
+
+=item C<PMC* get_number_pmc(PARROT_INTERP, FLOATVAL value)>
+
+Lookup the PMC type which is used for floating point numbers.
+
+=cut
+
+*/
+
+PARROT_CANNOT_RETURN_NULL
+PMC*
+get_number_pmc(PARROT_INTERP, FLOATVAL value)
+{
+    ASSERT_ARGS(get_number_pmc)
+    PMC * const ret = pmc_new(interp, Parrot_get_ctx_HLL_type(interp, enum_class_Float));
+    VTABLE_set_number_native(interp, ret, value);
+    return ret;
+}
+
+/*
+
+=item C<PMC * get_string_pmc(PARROT_INTERP, STRING *value)>
+
+Lookup the PMC type which is used for storing strings.
+
+=cut
+
+*/
+
+PARROT_CANNOT_RETURN_NULL
+PMC *
+get_string_pmc(PARROT_INTERP, ARGIN(STRING *value))
+{
+    ASSERT_ARGS(get_string_pmc)
+    PMC * const ret = pmc_new(interp, Parrot_get_ctx_HLL_type(interp, enum_class_String));
+    VTABLE_set_string_native(interp, ret, value);
+    return ret;
+}
+
+
+/*
+
+Poor-man polymorphic functions to convert something to something.
+
+There is bunch of functions to convert from passed value to stored keys type and to/from
+stored values type.
+
+void *hash_key_from_TYPE convert to keys type.
+TYPE hash_key_to_TYPE convert from keys type.
+void *hash_value_from_TYPE convert to values type.
+TYPE hash_value_to_TYPE convert from values type.
+
+*/
+
+/*
+
+=item C<void* hash_key_from_int(PARROT_INTERP, const Hash * const hash, INTVAL
+key)>
+
+Cast INTVAL to hash key.
+
+=cut
+
+*/
+
+PARROT_CAN_RETURN_NULL
+void*
+hash_key_from_int(PARROT_INTERP, ARGIN(const Hash * const hash), INTVAL key)
+{
+    ASSERT_ARGS(hash_key_from_int)
+    void *ret;
+    switch (hash->key_type) {
+      case Hash_key_type_int:
+        ret = (void *)key;
+        break;
+        /* Currently PMCs are stringified */
+      case Hash_key_type_PMC:
+        ret = (void *)get_integer_pmc(interp, key);
+        break;
+      case Hash_key_type_STRING:
+        ret = (void *)Parrot_str_from_int(interp, key);
+        break;
+      default:
+        Parrot_ex_throw_from_c_args(interp, NULL, EXCEPTION_UNIMPLEMENTED,
+                    "Hash: unsupported key_type");
+    }
+    return ret;
+}
+
+/*
+
+=item C<void* hash_key_from_string(PARROT_INTERP, const Hash * const hash,
+STRING *key)>
+
+Cast STRING to hash key.
+
+=cut
+
+*/
+
+PARROT_CAN_RETURN_NULL
+void*
+hash_key_from_string(PARROT_INTERP, ARGIN(const Hash * const hash), ARGIN(STRING *key))
+{
+    ASSERT_ARGS(hash_key_from_string)
+    void *ret;
+    switch (hash->key_type) {
+      case Hash_key_type_int:
+      {
+        /* Pacify compiler about casting INVTAL to void */
+        const INTVAL int_key = Parrot_str_to_int(interp, key);
+        ret                  = INTVAL2PTR(void *, int_key);
+        break;
+      }
+
+      case Hash_key_type_PMC:
+        ret = get_string_pmc(interp, key);
+        break;
+
+      case Hash_key_type_STRING:
+        ret = key;
+        break;
+
+      default:
+        Parrot_ex_throw_from_c_args(interp, NULL, EXCEPTION_UNIMPLEMENTED,
+                    "Hash: unsupported key_type");
+    }
+    return ret;
+}
+
+/*
+
+=item C<void* hash_key_from_pmc(PARROT_INTERP, const Hash * const hash, PMC
+*key)>
+
+Cast PMC* to hash key.
+
+=cut
+
+*/
+
+PARROT_CAN_RETURN_NULL
+void*
+hash_key_from_pmc(PARROT_INTERP, ARGIN(const Hash * const hash), ARGIN(PMC *key))
+{
+    ASSERT_ARGS(hash_key_from_pmc)
+    void *ret;
+    switch (hash->key_type) {
+      case Hash_key_type_int:
+        {
+            const INTVAL int_key = VTABLE_get_integer(interp, key);
+            ret                  = INTVAL2PTR(void *, int_key);
+            break;
+        }
+      case Hash_key_type_PMC:
+        {
+            /* Extract real value from Key (and box it if nessary) */
+            if (key->vtable->base_type == enum_class_Key)
+                switch (key_type(interp, key)) {
+                  case KEY_integer_FLAG:
+                    key = get_integer_pmc(interp, key_integer(interp, key));
+                    break;
+                  case KEY_string_FLAG:
+                    key = get_string_pmc(interp, key_string(interp, key));
+                    break;
+                  case KEY_number_FLAG:
+                    key = get_number_pmc(interp, key_number(interp, key));
+                    break;
+                  case KEY_pmc_FLAG:
+                    key = key_pmc(interp, key);
+                    break;
+                  default:
+                    /* It's impossible if Keys are same (and they are not) */
+                    /* So throw exception */
+                    Parrot_ex_throw_from_c_args(interp, NULL, EXCEPTION_INVALID_OPERATION,
+                                "hash: unexpected type of Key");
+                    break;
+                }
+
+            ret = key;
+            break;
+        }
+      case Hash_key_type_STRING:
+        {
+            STRING * const tmp = VTABLE_get_string(interp, key);
+            if (!tmp)
+                Parrot_ex_throw_from_c_args(interp, NULL, EXCEPTION_UNEXPECTED_NULL,
+                            "hash: can't use null as key");
+            ret = (void *)tmp;
+        }
+        break;
+      default:
+        Parrot_ex_throw_from_c_args(interp, NULL, EXCEPTION_UNIMPLEMENTED,
+                    "Hash: unsupported key_type");
+    }
+    return ret;
+}
+
+/*
+
+=item C<INTVAL hash_key_to_int(PARROT_INTERP, const Hash * const hash, void
+*key)>
+
+Cast hash key to INTVAL.
+
+=cut
+
+*/
+
+INTVAL
+hash_key_to_int(PARROT_INTERP, ARGIN(const Hash * const hash), ARGIN_NULLOK(void *key))
+{
+    ASSERT_ARGS(hash_key_to_int)
+    INTVAL ret;
+    switch (hash->key_type) {
+      case Hash_key_type_int:
+        ret = (INTVAL)key;
+        break;
+      case Hash_key_type_PMC:
+        ret = VTABLE_get_integer(interp, (PMC *)key);
+        break;
+      case Hash_key_type_STRING:
+        ret = Parrot_str_to_int(interp, (STRING *)key);
+        break;
+      default:
+        Parrot_ex_throw_from_c_args(interp, NULL, EXCEPTION_UNIMPLEMENTED,
+                    "Hash: unsupported key_type");
+    }
+    return ret;
+}
+
+/*
+
+=item C<STRING* hash_key_to_string(PARROT_INTERP, const Hash * const hash, void
+*key)>
+
+Cast hash key to STRING.
+
+=cut
+
+*/
+
+PARROT_CANNOT_RETURN_NULL
+STRING*
+hash_key_to_string(PARROT_INTERP, ARGIN(const Hash * const hash), ARGIN_NULLOK(void *key))
+{
+    ASSERT_ARGS(hash_key_to_string)
+    STRING *ret;
+    switch (hash->key_type) {
+      case Hash_key_type_int:
+        ret = Parrot_str_from_int(interp, (INTVAL)key);
+        break;
+
+      case Hash_key_type_PMC:
+        ret = VTABLE_get_string(interp, (PMC *)key);
+        break;
+
+      case Hash_key_type_STRING:
+        ret = (STRING *)key;
+        break;
+
+      default:
+        Parrot_ex_throw_from_c_args(interp, NULL, EXCEPTION_UNIMPLEMENTED,
+                    "Hash: unsupported key_type");
+    }
+    return ret;
+}
+
+/*
+
+=item C<PMC* hash_key_to_pmc(PARROT_INTERP, const Hash * const hash, void *key)>
+
+Cast hash key to PMC*.
+
+=cut
+
+*/
+
+PARROT_CANNOT_RETURN_NULL
+PMC*
+hash_key_to_pmc(PARROT_INTERP, ARGIN(const Hash * const hash), ARGIN(void *key))
+{
+    ASSERT_ARGS(hash_key_to_pmc)
+    PMC *ret;
+    switch (hash->key_type) {
+      case Hash_key_type_int:
+        ret = get_integer_pmc(interp, (INTVAL)key);
+        break;
+      case Hash_key_type_PMC:
+        ret = (PMC*)key;
+        break;
+      case Hash_key_type_STRING:
+        ret = get_string_pmc(interp, (STRING*)key);
+        break;
+      default:
+        Parrot_ex_throw_from_c_args(interp, NULL, EXCEPTION_UNIMPLEMENTED,
+                    "Hash: unsupported key_type");
+    }
+    return ret;
+}
+
+/* Second part - convert from stored void* to real type */
+/* TODO: FLOATVALs converted into Float PMC for now */
+
+/*
+
+=item C<void* hash_value_from_int(PARROT_INTERP, const Hash * const hash, INTVAL
+value)>
+
+Cast INTVAL to hash value.
+
+=cut
+
+*/
+
+PARROT_CAN_RETURN_NULL
+void*
+hash_value_from_int(PARROT_INTERP, ARGIN(const Hash * const hash), INTVAL value)
+{
+    ASSERT_ARGS(hash_value_from_int)
+    void *ret;
+    switch (hash->entry_type) {
+      case enum_type_INTVAL:
+        ret = INTVAL2PTR(void *, value);
+        break;
+      case enum_type_PMC:
+        {
+            PMC * const tmp = get_integer_pmc(interp, value);
+            ret = (void *)tmp;
+        }
+        break;
+      case enum_type_STRING:
+        ret = (void *)Parrot_str_from_int(interp, value);
+        break;
+      default:
+        Parrot_ex_throw_from_c_args(interp, NULL, EXCEPTION_UNIMPLEMENTED,
+                    "Hash: unsupported entry_type");
+    }
+    return ret;
+}
+
+/*
+
+=item C<void* hash_value_from_string(PARROT_INTERP, const Hash * const hash,
+STRING *value)>
+
+Cast STRING to hash value.
+
+=cut
+
+*/
+
+PARROT_CAN_RETURN_NULL
+void*
+hash_value_from_string(PARROT_INTERP, ARGIN(const Hash * const hash),
+        ARGIN_NULLOK(STRING *value))
+{
+    ASSERT_ARGS(hash_value_from_string)
+    void *ret;
+    switch (hash->entry_type) {
+      case enum_type_INTVAL:
+        {
+            const INTVAL int_val = STRING_IS_NULL(value) ?
+                    (INTVAL) 0 : Parrot_str_to_int(interp, value);
+            ret = INTVAL2PTR(void *, int_val);
+        }
+        break;
+      case enum_type_STRING:
+        ret = (void *)value;
+        break;
+      case enum_type_PMC:
+        {
+            PMC * const s = STRING_IS_NULL(value) ?
+                   PMCNULL : get_string_pmc(interp, value);
+            ret = (void *)s;
+        }
+        break;
+      default:
+        Parrot_ex_throw_from_c_args(interp, NULL, EXCEPTION_UNIMPLEMENTED,
+                    "Hash: unsupported entry_type");
+    }
+    return ret;
+}
+
+/*
+
+=item C<void* hash_value_from_pmc(PARROT_INTERP, const Hash * const hash, PMC
+*value)>
+
+Cast PMC to hash value.
+
+=cut
+
+*/
+
+PARROT_CAN_RETURN_NULL
+void*
+hash_value_from_pmc(PARROT_INTERP, ARGIN(const Hash * const hash),
+    ARGIN_NULLOK(PMC *value))
+{
+    ASSERT_ARGS(hash_value_from_pmc)
+    void *ret;
+    switch (hash->entry_type) {
+      case enum_type_INTVAL:
+        {
+            const INTVAL int_val = PMC_IS_NULL(value) ?
+                    (INTVAL) 0 : VTABLE_get_integer(interp, value);
+            ret                  = INTVAL2PTR(void *, int_val);
+        }
+        break;
+      case enum_type_STRING:
+        ret = PMC_IS_NULL(value) ?
+                PMCNULL : (void *)VTABLE_get_string(interp, value);
+        break;
+      case enum_type_PMC:
+        ret = (void *)value;
+        break;
+      default:
+        Parrot_ex_throw_from_c_args(interp, NULL, EXCEPTION_UNIMPLEMENTED,
+                    "Hash: unsupported entry_type");
+    }
+    return ret;
+}
+
+/*
+
+=item C<void* hash_value_from_number(PARROT_INTERP, const Hash * const hash,
+FLOATVAL value)>
+
+Cast FLOATVAL to hash value.
+
+=cut
+
+*/
+
+PARROT_CAN_RETURN_NULL
+void*
+hash_value_from_number(PARROT_INTERP, ARGIN(const Hash * const hash), FLOATVAL value)
+{
+    ASSERT_ARGS(hash_value_from_number)
+    void *ret;
+    switch (hash->entry_type) {
+      case enum_type_INTVAL:
+        {
+            const INTVAL tmp = value;
+            ret = (void*)tmp;
+        }
+        break;
+      case enum_type_STRING:
+        ret = (void *)Parrot_str_from_num(interp, value);
+        break;
+      case enum_type_PMC:
+        {
+            PMC * const tmp = get_number_pmc(interp, value);
+            ret = (void *)tmp;
+        }
+        break;
+      default:
+        Parrot_ex_throw_from_c_args(interp, NULL, EXCEPTION_UNIMPLEMENTED,
+                    "Hash: unsupported entry_type");
+    }
+    return ret;
+}
+
+/*
+
+=item C<INTVAL hash_value_to_int(PARROT_INTERP, const Hash * const hash, void
+*value)>
+
+Cast hash value to INTVAL.
+
+=cut
+
+*/
+
+INTVAL
+hash_value_to_int(PARROT_INTERP, ARGIN(const Hash * const hash), ARGIN_NULLOK(void *value))
+{
+    ASSERT_ARGS(hash_value_to_int)
+    INTVAL ret;
+    switch (hash->entry_type) {
+      case enum_type_ptr:
+      case enum_type_INTVAL:
+        ret = (INTVAL)value;
+        break;
+      case enum_type_STRING:
+        ret = Parrot_str_to_int(interp, (STRING*)value);
+        break;
+      case enum_type_PMC:
+        ret = VTABLE_get_integer(interp, (PMC*)value);
+        break;
+      default:
+        Parrot_ex_throw_from_c_args(interp, NULL, EXCEPTION_UNIMPLEMENTED,
+                    "Hash: unsupported entry_type");
+    }
+    return ret;
+}
+
+/*
+
+=item C<STRING* hash_value_to_string(PARROT_INTERP, const Hash * const hash,
+void *value)>
+
+Cast hash value to STRING.
+
+=cut
+
+*/
+
+PARROT_CANNOT_RETURN_NULL
+STRING*
+hash_value_to_string(PARROT_INTERP, ARGIN(const Hash * const hash), ARGIN_NULLOK(void *value))
+{
+    ASSERT_ARGS(hash_value_to_string)
+    STRING *ret;
+    switch (hash->entry_type) {
+      case enum_type_INTVAL:
+        ret = Parrot_str_from_int(interp, (INTVAL)value);
+        break;
+      case enum_type_STRING:
+        ret = (STRING *)value;
+        break;
+      case enum_type_PMC:
+        ret = VTABLE_get_string(interp, (PMC *)value);
+        break;
+      default:
+        Parrot_ex_throw_from_c_args(interp, NULL, EXCEPTION_UNIMPLEMENTED,
+                    "Hash: unsupported entry_type");
+    }
+    return ret;
+}
+
+/*
+
+=item C<PMC* hash_value_to_pmc(PARROT_INTERP, const Hash * const hash, void
+*value)>
+
+Cast hash value to PMC.
+
+=cut
+
+*/
+
+PARROT_CANNOT_RETURN_NULL
+PMC*
+hash_value_to_pmc(PARROT_INTERP, ARGIN(const Hash * const hash), ARGIN_NULLOK(void *value))
+{
+    ASSERT_ARGS(hash_value_to_pmc)
+    PMC *ret;
+    switch (hash->entry_type) {
+      case enum_type_INTVAL:
+        ret = get_integer_pmc(interp, (INTVAL)value);
+        break;
+      case enum_type_STRING:
+        ret = get_string_pmc(interp, (STRING*)value);
+        break;
+      case enum_type_PMC:
+        ret = (PMC *)value;
+        break;
+      default:
+        Parrot_ex_throw_from_c_args(interp, NULL, EXCEPTION_UNIMPLEMENTED,
+                    "Hash: unsupported entry_type");
+    }
+    return ret;
+}
+
+/*
+
+=item C<FLOATVAL hash_value_to_number(PARROT_INTERP, const Hash * const hash,
+void *value)>
+
+Cast hash value to FLOATVAL.
+
+=cut
+
+*/
+
+FLOATVAL
+hash_value_to_number(PARROT_INTERP, ARGIN(const Hash * const hash), ARGIN_NULLOK(void *value))
+{
+    ASSERT_ARGS(hash_value_to_number)
+    FLOATVAL ret;
+    switch (hash->entry_type) {
+      case enum_type_INTVAL:
+        {
+            /* Pacify compiler about casting */
+            const INTVAL tmp = (INTVAL)value;
+            ret = tmp;
+        }
+        break;
+      case enum_type_STRING:
+        ret = Parrot_str_to_num(interp, (STRING*)value);
+        break;
+      case enum_type_PMC:
+        ret = VTABLE_get_number(interp, (PMC*)value);
+        break;
+      default:
+        Parrot_ex_throw_from_c_args(interp, NULL, EXCEPTION_UNIMPLEMENTED,
+                    "Hash: unsupported entry_type");
+    }
+    return ret;
+}
+
+/*
+
 =back
 
 =head1 SEE ALSO
