@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2001-2009, Parrot Foundation.
-$Id: api.c 40085 2009-07-14 17:16:22Z Util $
+$Id$
 
 =head1 NAME
 
@@ -30,8 +30,8 @@ src/io/io_string.c.
 #include "parrot/parrot.h"
 #include "io_private.h"
 #include "api.str"
-#include "../pmc/pmc_filehandle.h"
-#include "../pmc/pmc_stringhandle.h"
+#include "pmc/pmc_filehandle.h"
+#include "pmc/pmc_stringhandle.h"
 
 #include <stdarg.h>
 
@@ -151,7 +151,7 @@ Parrot_io_open(PARROT_INTERP, ARGIN_NULLOK(PMC *pmc),
         filehandle = pmc;
     }
     else
-        Parrot_PCCINVOKE(interp, new_filehandle, CONST_STRING(interp, "open"), "SS->P", path, mode, &filehandle);
+        Parrot_pcc_invoke_method_from_c_args(interp, new_filehandle, CONST_STRING(interp, "open"), "SS->P", path, mode, &filehandle);
     return filehandle;
 }
 
@@ -212,7 +212,7 @@ PMC object.
 
 PARROT_EXPORT
 INTVAL
-Parrot_io_close(PARROT_INTERP, ARGMOD(PMC *pmc))
+Parrot_io_close(PARROT_INTERP, ARGMOD_NULLOK(PMC *pmc))
 {
     ASSERT_ARGS(Parrot_io_close)
     INTVAL result = 1;
@@ -228,7 +228,7 @@ Parrot_io_close(PARROT_INTERP, ARGMOD(PMC *pmc))
         SETATTR_StringHandle_read_offset(interp, pmc, 0);
     }
     else
-        Parrot_PCCINVOKE(interp, pmc, CONST_STRING(interp, "close"), "->I", &result);
+        Parrot_pcc_invoke_method_from_c_args(interp, pmc, CONST_STRING(interp, "close"), "->I", &result);
 
     return result;
 }
@@ -283,7 +283,7 @@ Parrot_io_is_closed(PARROT_INTERP, ARGMOD(PMC *pmc))
         result = STRING_IS_NULL(stringhandle);
     }
     else
-        Parrot_PCCINVOKE(interp, pmc, CONST_STRING(interp, "is_closed"), "->I", &result);
+        Parrot_pcc_invoke_method_from_c_args(interp, pmc, CONST_STRING(interp, "is_closed"), "->I", &result);
 
     return result;
 }
@@ -301,7 +301,7 @@ filehandle PMC.
 
 PARROT_EXPORT
 void
-Parrot_io_flush(PARROT_INTERP, ARGMOD(PMC *pmc))
+Parrot_io_flush(PARROT_INTERP, ARGMOD_NULLOK(PMC *pmc))
 {
     ASSERT_ARGS(Parrot_io_flush)
     if (PMC_IS_NULL(pmc))
@@ -313,7 +313,7 @@ Parrot_io_flush(PARROT_INTERP, ARGMOD(PMC *pmc))
         SETATTR_StringHandle_stringhandle(interp, pmc, NULL);
     }
     else
-        Parrot_PCCINVOKE(interp, pmc, CONST_STRING(interp, "flush"), "->");
+        Parrot_pcc_invoke_method_from_c_args(interp, pmc, CONST_STRING(interp, "flush"), "->");
 }
 
 /*
@@ -385,7 +385,7 @@ Parrot_io_reads(PARROT_INTERP, ARGMOD(PMC *pmc), size_t length)
         }
     }
     else
-        Parrot_PCCINVOKE(interp, pmc, CONST_STRING(interp, "read"), "I->S", length, &result);
+        Parrot_pcc_invoke_method_from_c_args(interp, pmc, CONST_STRING(interp, "read"), "I->S", length, &result);
     return result;
 }
 
@@ -443,7 +443,7 @@ Parrot_io_readline(PARROT_INTERP, ARGMOD(PMC *pmc))
         SETATTR_StringHandle_read_offset(interp, pmc, newline_pos + 1);
     }
     else
-        Parrot_PCCINVOKE(interp, pmc, CONST_STRING(interp, "readline"), "->S", &result);
+        Parrot_pcc_invoke_method_from_c_args(interp, pmc, CONST_STRING(interp, "readline"), "->S", &result);
     return result;
 }
 
@@ -466,17 +466,14 @@ Parrot_io_write(PARROT_INTERP, ARGMOD(PMC *pmc), ARGIN(const void *buffer), size
     ASSERT_ARGS(Parrot_io_write)
     DECL_CONST_CAST;
     INTVAL result;
-    STRING fake;
+    STRING *s;
 
     if (PMC_IS_NULL(pmc))
         return -1;
 
-    fake.strstart = (char *) PARROT_const_cast(void *, buffer);
-    fake.strlen = fake.bufused = length;
-    fake.charset = Parrot_default_charset_ptr;
-    fake.encoding = Parrot_default_encoding_ptr;
+    s = Parrot_str_new(interp, (char *) PARROT_const_cast(void *, buffer), length);
 
-    result = Parrot_io_putps(interp, pmc, &fake);
+    result = Parrot_io_putps(interp, pmc, s);
     return result;
 }
 
@@ -584,7 +581,7 @@ Parrot_io_eof(PARROT_INTERP, ARGMOD(PMC *pmc))
             return 1;
         return 0;
     }
-    Parrot_PCCINVOKE(interp, pmc, CONST_STRING(interp, "eof"), "->I", &result);
+    Parrot_pcc_invoke_method_from_c_args(interp, pmc, CONST_STRING(interp, "eof"), "->I", &result);
     return result;
 }
 
@@ -642,7 +639,7 @@ Parrot_io_putps(PARROT_INTERP, ARGMOD(PMC *pmc), ARGMOD_NULLOK(STRING *s))
             result = Parrot_io_write_buffer(interp, pmc, s);
     }
     else
-        Parrot_PCCINVOKE(interp, pmc, CONST_STRING(interp, "puts"), "S->I", s, &result);
+        Parrot_pcc_invoke_method_from_c_args(interp, pmc, CONST_STRING(interp, "puts"), "S->I", s, &result);
 
     return result;
 
