@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2001-2009, Parrot Foundation.
-$Id: buffer.c 40140 2009-07-18 05:07:29Z petdance $
+$Id$
 
 =head1 NAME
 
@@ -28,8 +28,8 @@ This file implements a collection of utility functions for I/O buffering.
 static INTVAL io_is_end_of_line(ARGIN(const char *c))
         __attribute__nonnull__(1);
 
-#define ASSERT_ARGS_io_is_end_of_line __attribute__unused__ int _ASSERT_ARGS_CHECK = \
-       PARROT_ASSERT_ARG(c)
+#define ASSERT_ARGS_io_is_end_of_line __attribute__unused__ int _ASSERT_ARGS_CHECK = (\
+       PARROT_ASSERT_ARG(c))
 /* Don't modify between HEADERIZER BEGIN / HEADERIZER END.  Your changes will be lost. */
 /* HEADERIZER END: static */
 
@@ -83,17 +83,17 @@ Parrot_io_setbuf(PARROT_INTERP, ARGMOD(PMC *filehandle), size_t bufsize)
 
     /* Choose an appropriate buffer size for caller */
     switch (bufsize) {
-        case 0:
-            Parrot_io_set_buffer_size(interp, filehandle, 0);
-            break;
-        case PIO_UNBOUND:
-            Parrot_io_set_buffer_size(interp, filehandle,
+      case 0:
+        Parrot_io_set_buffer_size(interp, filehandle, 0);
+        break;
+      case PIO_UNBOUND:
+        Parrot_io_set_buffer_size(interp, filehandle,
                     PIO_GETBLKSIZE(Parrot_io_get_os_handle(interp, filehandle)));
-            break;
-        default:
-            Parrot_io_set_buffer_size(interp, filehandle,
+        break;
+      default:
+        Parrot_io_set_buffer_size(interp, filehandle,
                     (bufsize >= PIO_GRAIN ? bufsize : PIO_GRAIN));
-            break;
+        break;
     }
 
     buffer_size = Parrot_io_get_buffer_size(interp, filehandle);
@@ -173,9 +173,6 @@ INTVAL
 Parrot_io_flush_buffer(PARROT_INTERP, ARGMOD(PMC *filehandle))
 {
     ASSERT_ARGS(Parrot_io_flush_buffer)
-    long wrote;
-    size_t to_write;
-    STRING fake;
     unsigned char *buffer_start = Parrot_io_get_buffer_start(interp, filehandle);
     unsigned char *buffer_next  = Parrot_io_get_buffer_next(interp, filehandle);
     INTVAL         buffer_flags = Parrot_io_get_buffer_flags(interp, filehandle);
@@ -191,12 +188,10 @@ Parrot_io_flush_buffer(PARROT_INTERP, ARGMOD(PMC *filehandle))
      * Write flush
      */
     if (buffer_flags & PIO_BF_WRITEBUF) {
-        to_write = buffer_next - buffer_start;
-
+        size_t  to_write = buffer_next - buffer_start;
+        STRING *s        = Parrot_str_new(interp, (char *)buffer_start, to_write);
         /* Flush to next layer */
-        fake.strstart = (char *)buffer_start;
-        fake.bufused = to_write;
-        wrote = PIO_WRITE(interp, filehandle, &fake);
+        long wrote = PIO_WRITE(interp, filehandle, s);
         if (wrote == (long)to_write) {
             Parrot_io_set_buffer_next(interp, filehandle, buffer_start);
             /* Release buffer */
@@ -238,10 +233,9 @@ Parrot_io_fill_readbuf(PARROT_INTERP, ARGMOD(PMC *filehandle))
     STRING  *s    = &fake;
     PIOOFF_T pos  = Parrot_io_get_file_position(interp, filehandle);
 
-    fake.strstart = (char *)Parrot_io_get_buffer_start(interp, filehandle);
-    fake.bufused  = Parrot_io_get_buffer_size(interp, filehandle);
-
-    got           = PIO_READ(interp, filehandle, &s);
+    Buffer_bufstart(s) = Parrot_io_get_buffer_start(interp, filehandle);
+    fake.bufused       = Parrot_io_get_buffer_size(interp, filehandle);
+    got                = PIO_READ(interp, filehandle, &s);
 
     /* buffer-filling does not change fileposition */
     Parrot_io_set_file_position(interp, filehandle, pos);
@@ -352,10 +346,10 @@ Parrot_io_read_buffer(PARROT_INTERP, ARGMOD(PMC *filehandle),
             STRING     fake;
             STRING    *sf = &fake;
 
-            fake.strstart = (char *)out_buf;
-            fake.bufused  = len;
-            got           = PIO_READ(interp, filehandle, &sf);
-            s->strlen     = s->bufused = current + got;
+            Buffer_bufstart(sf) = (char *)out_buf;
+            fake.bufused        = len;
+            got                 = PIO_READ(interp, filehandle, &sf);
+            s->strlen           = s->bufused = current + got;
 
             Parrot_io_set_file_position(interp, filehandle,
                     (got + Parrot_io_get_file_position(interp, filehandle)));
@@ -571,7 +565,6 @@ size_t
 Parrot_io_write_buffer(PARROT_INTERP, ARGMOD(PMC *filehandle), ARGIN(STRING *s))
 {
     ASSERT_ARGS(Parrot_io_write_buffer)
-    void          * const buffer       = s->strstart;
     unsigned char * const buffer_start = Parrot_io_get_buffer_start(interp, filehandle);
     unsigned char *       buffer_next  = Parrot_io_get_buffer_next(interp, filehandle);
     const size_t          buffer_size  = Parrot_io_get_buffer_size(interp, filehandle);
@@ -602,7 +595,7 @@ Parrot_io_write_buffer(PARROT_INTERP, ARGMOD(PMC *filehandle), ARGIN(STRING *s))
 
     if (Parrot_io_get_flags(interp, filehandle) & PIO_F_LINEBUF) {
         /* scan from end, it's likely that EOL is at end of string */
-        const char *p = (char*)buffer + len - 1;
+        const char *p = (char*)(s->strstart) + len - 1;
         size_t      i;
 
         for (i = 0; i < len; ++i, --p) {
@@ -639,7 +632,7 @@ Parrot_io_write_buffer(PARROT_INTERP, ARGMOD(PMC *filehandle), ARGIN(STRING *s))
         buffer_flags |= PIO_BF_WRITEBUF;
         Parrot_io_set_buffer_flags(interp, filehandle, buffer_flags);
 
-        memmove(buffer_next, buffer, len);
+        memmove(buffer_next, s->strstart, len);
         buffer_next += len;
         Parrot_io_set_buffer_next(interp, filehandle, buffer_next);
         Parrot_io_set_file_position(interp, filehandle, (len +
@@ -653,7 +646,7 @@ Parrot_io_write_buffer(PARROT_INTERP, ARGMOD(PMC *filehandle), ARGIN(STRING *s))
         Parrot_io_set_buffer_flags(interp, filehandle, buffer_flags);
 
         /* Fill remainder, flush, then try to buffer more */
-        memmove(buffer_next, buffer, avail);
+        memmove(buffer_next, s->strstart, avail);
         buffer_next += avail;
         Parrot_io_set_buffer_next(interp, filehandle, buffer_next);
         Parrot_io_set_file_position(interp, filehandle, (avail +
@@ -664,7 +657,7 @@ Parrot_io_write_buffer(PARROT_INTERP, ARGMOD(PMC *filehandle), ARGIN(STRING *s))
         Parrot_io_set_buffer_flags(interp, filehandle, buffer_flags);
 
         buffer_next = Parrot_io_get_buffer_next(interp, filehandle);
-        memmove(buffer_start, ((const char *)buffer + avail), diff);
+        memmove(buffer_start, (s->strstart + avail), diff);
 
         buffer_next += diff;
         Parrot_io_set_buffer_next(interp, filehandle, buffer_next);
@@ -698,20 +691,20 @@ Parrot_io_seek_buffer(PARROT_INTERP, ARGMOD(PMC *filehandle),
     unsigned char *buffer_end   = Parrot_io_get_buffer_end(interp, filehandle);
 
     switch (whence) {
-    case SEEK_SET:
+      case SEEK_SET:
         newpos = offset;
         break;
-    case SEEK_CUR:
+      case SEEK_CUR:
         newpos = file_pos + offset;
         break;
-    case SEEK_END:
+      case SEEK_END:
         newpos = PIO_SEEK(interp, filehandle, offset,
                                whence);
         if (newpos == -1)
             return -1;
 
         break;
-    default:
+      default:
         /* XXX: somehow report the illegal whence value */
         return -1;
     }
