@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2001-2009, Parrot Foundation.
-$Id: socket_win32.c 38732 2009-05-13 00:57:03Z whiteknight $
+$Id$
 
 =head1 NAME
 
@@ -28,7 +28,7 @@ Win32 System Programming, 2nd Edition.
 
 #include "parrot/parrot.h"
 #include "io_private.h"
-#include "../pmc/pmc_socket.h"
+#include "pmc/pmc_socket.h"
 
 #ifdef PIO_OS_WIN32
 
@@ -44,10 +44,10 @@ static void get_sockaddr_in(PARROT_INTERP,
         __attribute__nonnull__(2)
         __attribute__nonnull__(3);
 
-#define ASSERT_ARGS_get_sockaddr_in __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+#define ASSERT_ARGS_get_sockaddr_in __attribute__unused__ int _ASSERT_ARGS_CHECK = (\
        PARROT_ASSERT_ARG(interp) \
-    || PARROT_ASSERT_ARG(sockaddr) \
-    || PARROT_ASSERT_ARG(host)
+    , PARROT_ASSERT_ARG(sockaddr) \
+    , PARROT_ASSERT_ARG(host))
 /* Don't modify between HEADERIZER BEGIN / HEADERIZER END.  Your changes will be lost. */
 /* HEADERIZER END: static */
 
@@ -77,8 +77,8 @@ INTVAL
 Parrot_io_socket_win32(PARROT_INTERP, ARGIN(PMC * s), int fam, int type, int proto)
 {
     ASSERT_ARGS(Parrot_io_socket_win32)
-    int sock, i = 1;
-    sock = socket(fam, type, proto);
+    int       i    = 1;
+    const int sock = socket(fam, type, proto);
     if (sock >= 0) {
         setsockopt(sock, SOL_SOCKET, SO_REUSEADDR, (const char*)&i, sizeof (i));
         Parrot_io_set_os_handle(interp, s, sock);
@@ -113,14 +113,14 @@ AGAIN:
     if ((connect((int)io->os_handle, (struct sockaddr *)SOCKADDR_REMOTE(socket),
             sizeof (struct sockaddr_in))) != 0) {
         switch (errno) {
-            case WSAEINTR:
-                goto AGAIN;
-            case WSAEINPROGRESS:
-                goto AGAIN;
-            case WSAEISCONN:
-                return 0;
-            default:
-                return -1;
+          case WSAEINTR:
+            goto AGAIN;
+          case WSAEINPROGRESS:
+            goto AGAIN;
+          case WSAEISCONN:
+            return 0;
+          default:
+            return -1;
         }
     }
 
@@ -259,21 +259,21 @@ AGAIN:
     }
     else {
         switch (errno) {
-            case WSAEINTR:
-                goto AGAIN;
+          case WSAEINTR:
+            goto AGAIN;
 #    ifdef WSAEWOULDBLOCK
-            case WSAEWOULDBLOCK:
-                goto AGAIN;
+          case WSAEWOULDBLOCK:
+            goto AGAIN;
 #    else
-            case WSAEAGAIN:
-                goto AGAIN;
+          case WSAEAGAIN:
+            goto AGAIN;
 #    endif
-            case EPIPE:
-                /* XXX why close it here and not below */
-                close((int)io->os_handle);
-                return -1;
-            default:
-                return -1;
+          case EPIPE:
+            /* XXX why close it here and not below */
+            close((int)io->os_handle);
+            return -1;
+          default:
+            return -1;
         }
     }
 }
@@ -308,24 +308,24 @@ AGAIN:
     }
     else {
         switch (errno) {
-            case EINTR:
-                goto AGAIN;
+          case EINTR:
+            goto AGAIN;
 #    ifdef WSAEWOULDBLOCK
-            case WSAEWOULDBLOCK:
-                goto AGAIN;
+          case WSAEWOULDBLOCK:
+            goto AGAIN;
 #    else
-            case WSAEAGAIN:
-                goto AGAIN;
+          case WSAEAGAIN:
+            goto AGAIN;
 #    endif
-            case WSAECONNRESET:
-                /* XXX why close it on err return result is -1 anyway */
-                close((int)io->os_handle);
-                *s = Parrot_str_new_noinit(interp, enum_stringrep_one, 0);
-                return -1;
-            default:
-                close((int)io->os_handle);
-                *s = Parrot_str_new_noinit(interp, enum_stringrep_one, 0);
-                return -1;
+          case WSAECONNRESET:
+            /* XXX why close it on err return result is -1 anyway */
+            close((int)io->os_handle);
+            *s = Parrot_str_new_noinit(interp, enum_stringrep_one, 0);
+            return -1;
+          default:
+            close((int)io->os_handle);
+            *s = Parrot_str_new_noinit(interp, enum_stringrep_one, 0);
+            return -1;
         }
     }
 }
@@ -339,12 +339,12 @@ Utility function for polling a single IO stream with a timeout.
 
 Returns a 1 | 2 | 4 (read, write, error) value.
 
-This is not equivalent to any speficic POSIX or BSD socket call, however
+This is not equivalent to any specific POSIX or BSD socket call, but
 it is a useful, common primitive.
 
 Not at all usefule --leo.
 
-Also, a buffering layer above this may choose to reimpliment by checking
+Also, a buffering layer above this may choose to reimplement by checking
 the read buffer.
 
 =cut
@@ -443,13 +443,11 @@ PMC *
 Parrot_io_sockaddr_in(PARROT_INTERP, ARGIN(STRING *addr), INTVAL port)
 {
     ASSERT_ARGS(Parrot_io_sockaddr_in)
-    PMC * sockaddr;
-    char * s;
-
-    s = Parrot_str_to_cstring(interp, addr);
+    PMC  * sockaddr;
+    char * const s = Parrot_str_to_cstring(interp, addr);
     sockaddr = pmc_new(interp, enum_class_Sockaddr);
     get_sockaddr_in(interp, sockaddr, s, port);
-    free(s);
+    Parrot_str_free_cstring(s);
     return sockaddr;
 }
 
