@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2001-2008, Parrot Foundation.
-$Id: key.c 39700 2009-06-22 04:48:36Z petdance $
+$Id$
 
 =head1 NAME
 
@@ -22,6 +22,7 @@ The base vtable calling functions.
 #include "parrot/key.h"
 #include "key.str"
 #include "pmc/pmc_key.h"
+#include "pmc/pmc_callcontext.h"
 
 /* HEADERIZER HFILE: include/parrot/key.h */
 
@@ -332,50 +333,40 @@ key_integer(PARROT_INTERP, ARGIN(PMC *key))
     FLOATVAL num_key;
 
     switch (PObj_get_FLAGS(key) & KEY_type_FLAGS) {
-        case KEY_hash_iterator_FLAGS:
+      case KEY_integer_FLAG:
+        GETATTR_Key_int_key(interp, key, int_key);
+        return int_key;
+      case KEY_integer_FLAG | KEY_register_FLAG:
+        GETATTR_Key_int_key(interp, key, int_key);
+        return REG_INT(interp, int_key);
 
-        case KEY_integer_FLAG:
-            GETATTR_Key_int_key(interp, key, int_key);
-            return int_key;
-        case KEY_integer_FLAG | KEY_register_FLAG:
-            GETATTR_Key_int_key(interp, key, int_key);
-            return REG_INT(interp, int_key);
+      case KEY_number_FLAG:
+        GETATTR_Key_num_key(interp, key, num_key);
+        return (INTVAL)num_key;
+      case KEY_number_FLAG | KEY_register_FLAG:
+        GETATTR_Key_int_key(interp, key, int_key);
+        return (INTVAL)REG_NUM(interp, int_key);
 
-        case KEY_number_FLAG:
-            GETATTR_Key_num_key(interp, key, num_key);
-            return (INTVAL)num_key;
-        case KEY_number_FLAG | KEY_register_FLAG:
-            GETATTR_Key_int_key(interp, key, int_key);
-            return (INTVAL)REG_NUM(interp, int_key);
-
-        case KEY_pmc_FLAG | KEY_register_FLAG:
-            {
+      case KEY_pmc_FLAG | KEY_register_FLAG:
+        {
             PMC *reg;
             GETATTR_Key_int_key(interp, key, int_key);
             reg = REG_PMC(interp, int_key);
             return VTABLE_get_integer(interp, reg);
-            }
+        }
 
-        case KEY_string_FLAG:
-            GETATTR_Key_str_key(interp, key, str_key);
-            return Parrot_str_to_int(interp, str_key);
-        case KEY_string_FLAG | KEY_register_FLAG:
-            {
+      case KEY_string_FLAG:
+        GETATTR_Key_str_key(interp, key, str_key);
+        return Parrot_str_to_int(interp, str_key);
+      case KEY_string_FLAG | KEY_register_FLAG:
+        {
             STRING *s_reg;
             GETATTR_Key_int_key(interp, key, int_key);
             s_reg = REG_STR(interp, int_key);
             return Parrot_str_to_int(interp, s_reg);
-            }
+        }
 
-        case KEY_string_FLAG | KEY_start_slice_FLAG:
-        case KEY_string_FLAG | KEY_inf_slice_FLAG:
-            {
-            STRING * const s_key = VTABLE_get_string(interp, key);
-            return Parrot_str_to_int(interp, s_key);
-            }
-        case KEY_start_slice_FLAG:
-        case KEY_inf_slice_FLAG:
-        default:
+      default:
             break;
     }
 
@@ -406,22 +397,22 @@ key_number(PARROT_INTERP, ARGIN(PMC *key))
     FLOATVAL num_key;
 
     switch (PObj_get_FLAGS(key) & KEY_type_FLAGS) {
-    case KEY_number_FLAG:
+      case KEY_number_FLAG:
         GETATTR_Key_num_key(interp, key, num_key);
         return num_key;
-    case KEY_number_FLAG | KEY_register_FLAG:
+      case KEY_number_FLAG | KEY_register_FLAG:
         GETATTR_Key_int_key(interp, key, int_key);
         return REG_NUM(interp, int_key);
-    case KEY_pmc_FLAG:
+      case KEY_pmc_FLAG:
         return VTABLE_get_number(interp, key);
-    case KEY_pmc_FLAG | KEY_register_FLAG:
+      case KEY_pmc_FLAG | KEY_register_FLAG:
         {
-        PMC *reg;
-        GETATTR_Key_int_key(interp, key, int_key);
-        reg = REG_PMC(interp, int_key);
-        return VTABLE_get_number(interp, reg);
+            PMC *reg;
+            GETATTR_Key_int_key(interp, key, int_key);
+            reg = REG_PMC(interp, int_key);
+            return VTABLE_get_number(interp, reg);
         }
-    default:
+      default:
         Parrot_ex_throw_from_c_args(interp, NULL, EXCEPTION_INVALID_OPERATION,
             "Key not a number!\n");
     }
@@ -448,7 +439,7 @@ key_string(PARROT_INTERP, ARGIN(PMC *key))
 
     switch (PObj_get_FLAGS(key) & KEY_type_FLAGS) {
         /* remember to COW strings instead of returning them directly */
-        case KEY_string_FLAG:
+      case KEY_string_FLAG:
         {
             STRING *s;
             GETATTR_Key_str_key(interp, key, s);
@@ -456,7 +447,7 @@ key_string(PARROT_INTERP, ARGIN(PMC *key))
                 s = Parrot_str_new_COW(interp, s);
             return s;
         }
-        case KEY_string_FLAG | KEY_register_FLAG:
+      case KEY_string_FLAG | KEY_register_FLAG:
         {
             INTVAL int_key;
             STRING *s;
@@ -466,7 +457,7 @@ key_string(PARROT_INTERP, ARGIN(PMC *key))
                 s = Parrot_str_new_COW(interp, s);
             return s;
         }
-        case KEY_pmc_FLAG | KEY_register_FLAG:
+      case KEY_pmc_FLAG | KEY_register_FLAG:
         {
             INTVAL int_key;
             PMC *reg;
@@ -474,33 +465,33 @@ key_string(PARROT_INTERP, ARGIN(PMC *key))
             reg = REG_PMC(interp, int_key);
             return VTABLE_get_string(interp, reg);
         }
-        case KEY_integer_FLAG:
+      case KEY_integer_FLAG:
         {
             INTVAL int_key;
             GETATTR_Key_int_key(interp, key, int_key);
             return Parrot_str_from_int(interp, int_key);
         }
-        case KEY_integer_FLAG | KEY_register_FLAG:
+      case KEY_integer_FLAG | KEY_register_FLAG:
         {
             INTVAL int_key;
             GETATTR_Key_int_key(interp, key, int_key);
             return Parrot_str_from_int(interp, REG_INT(interp, int_key));
         }
-        case KEY_number_FLAG:
+      case KEY_number_FLAG:
         {
             FLOATVAL num_key;
             GETATTR_Key_num_key(interp, key, num_key);
             return Parrot_str_from_num(interp, num_key);
         }
-        case KEY_number_FLAG | KEY_register_FLAG:
+      case KEY_number_FLAG | KEY_register_FLAG:
         {
             INTVAL int_key;
             GETATTR_Key_int_key(interp, key, int_key);
             return Parrot_str_from_num(interp, REG_NUM(interp, int_key));
         }
-        default:
-        case KEY_pmc_FLAG:
-            return VTABLE_get_string(interp, key);
+      default:
+      case KEY_pmc_FLAG:
+        return VTABLE_get_string(interp, key);
     }
 }
 
@@ -526,10 +517,10 @@ key_pmc(PARROT_INTERP, ARGIN(PMC *key))
     INTVAL int_key;
 
     switch (PObj_get_FLAGS(key) & KEY_type_FLAGS) {
-    case KEY_pmc_FLAG | KEY_register_FLAG:
+      case KEY_pmc_FLAG | KEY_register_FLAG:
         GETATTR_Key_int_key(interp, key, int_key);
         return REG_PMC(interp, int_key);
-    default:
+      default:
         return key;
     }
 }
@@ -554,7 +545,7 @@ key_next(PARROT_INTERP, ARGIN(PMC *key))
     ASSERT_ARGS(key_next)
     PMC *next_key;
 
-    if (VTABLE_isa(interp, key, CONST_STRING(interp, "Key")) && key->pmc_ext) {
+    if (VTABLE_isa(interp, key, CONST_STRING(interp, "Key"))) {
         GETATTR_Key_next_key(interp, key, next_key);
         return next_key;
     }
@@ -616,28 +607,19 @@ void
 key_mark(PARROT_INTERP, ARGIN(PMC *key))
 {
     ASSERT_ARGS(key_mark)
+    PMC          *next_key;
     const UINTVAL flags = PObj_get_FLAGS(key) & KEY_type_FLAGS;
 
     if (flags == KEY_string_FLAG) {
         STRING *str_key;
         GETATTR_Key_str_key(interp, key, str_key);
-
-        /* XXX str_key can be NULL from GETATTR_Key_str_key, */
-        /* so shouldn't be marked. */
-        Parrot_gc_mark_PObj_alive(interp, (PObj *)str_key);
+        Parrot_gc_mark_STRING_alive(interp, str_key);
     }
 
-    /*
-     * KEY_hash_iterator_FLAGS denote a hash key iteration, PMC_data() is
-     * the bucket_index and not the next key component
-     * Note to self: shoot whoever thought this was a good idea.
-     */
-    if (flags != KEY_hash_iterator_FLAGS) {
-        PMC *next_key;
-        /* if iteration hasn't started, above flag isn't set yet */
+    /* Mark next key */
+    if ((flags == KEY_string_FLAG) || (flags == KEY_pmc_FLAG)) {
         GETATTR_Key_next_key(interp, key, next_key);
-        if (next_key && (void *)next_key != (void *)INITBucketIndex)
-            Parrot_gc_mark_PObj_alive(interp, (PObj *)next_key);
+        Parrot_gc_mark_PMC_alive(interp, next_key);
     }
 
 }
@@ -671,57 +653,57 @@ key_set_to_string(PARROT_INTERP, ARGIN_NULLOK(PMC *key))
 
     while (key != NULL) {
         switch (PObj_get_FLAGS(key) & KEY_type_FLAGS) {
-            case KEY_integer_FLAG:
-                GETATTR_Key_int_key(interp, key, int_key);
-                value = Parrot_str_append(interp, value,
+          case KEY_integer_FLAG:
+            GETATTR_Key_int_key(interp, key, int_key);
+            value = Parrot_str_append(interp, value,
                     Parrot_str_from_int(interp, int_key));
-                break;
-            case KEY_number_FLAG:
-                GETATTR_Key_int_key(interp, key, int_key);
-                value = Parrot_str_append(interp, value,
+            break;
+          case KEY_number_FLAG:
+            GETATTR_Key_int_key(interp, key, int_key);
+            value = Parrot_str_append(interp, value,
                     Parrot_str_from_num(interp, (FLOATVAL)int_key));
-                break;
-            case KEY_string_FLAG:
-                GETATTR_Key_str_key(interp, key, str_key);
-                value = Parrot_str_append(interp, value, quote);
-                value = Parrot_str_append(interp, value, str_key);
-                value = Parrot_str_append(interp, value, quote);
-                break;
-            case KEY_pmc_FLAG:
-                value = Parrot_str_append(interp, value,
+            break;
+          case KEY_string_FLAG:
+            GETATTR_Key_str_key(interp, key, str_key);
+            value = Parrot_str_append(interp, value, quote);
+            value = Parrot_str_append(interp, value, str_key);
+            value = Parrot_str_append(interp, value, quote);
+            break;
+          case KEY_pmc_FLAG:
+            value = Parrot_str_append(interp, value,
                     VTABLE_get_string(interp, key));
-                break;
-            case KEY_integer_FLAG | KEY_register_FLAG:
-                GETATTR_Key_int_key(interp, key, int_key);
-                value = Parrot_str_append(interp, value,
+            break;
+          case KEY_integer_FLAG | KEY_register_FLAG:
+            GETATTR_Key_int_key(interp, key, int_key);
+            value = Parrot_str_append(interp, value,
                         Parrot_str_from_int(interp,
                             REG_INT(interp, int_key)));
-                break;
-            case KEY_number_FLAG | KEY_register_FLAG:
-                GETATTR_Key_int_key(interp, key, int_key);
-                value = Parrot_str_append(interp, value,
+            break;
+          case KEY_number_FLAG | KEY_register_FLAG:
+            GETATTR_Key_int_key(interp, key, int_key);
+            value = Parrot_str_append(interp, value,
                         Parrot_str_from_num(interp,
                             REG_NUM(interp, int_key)));
-                break;
-            case KEY_string_FLAG | KEY_register_FLAG:
-                value = Parrot_str_append(interp, value, quote);
-                GETATTR_Key_int_key(interp, key, int_key);
-                value = Parrot_str_append(interp, value,
+            break;
+          case KEY_string_FLAG | KEY_register_FLAG:
+            value = Parrot_str_append(interp, value, quote);
+            GETATTR_Key_int_key(interp, key, int_key);
+            value = Parrot_str_append(interp, value,
                     REG_STR(interp, int_key));
-                value = Parrot_str_append(interp, value, quote);
-                break;
-            case KEY_pmc_FLAG | KEY_register_FLAG:
-                {
+            value = Parrot_str_append(interp, value, quote);
+            break;
+          case KEY_pmc_FLAG | KEY_register_FLAG:
+            {
                 PMC *reg;
                 GETATTR_Key_int_key(interp, key, int_key);
                 reg = REG_PMC(interp, int_key);
                 value           = Parrot_str_append(interp, value,
                                     VTABLE_get_string(interp, reg));
-                }
-                break;
-            default:
-                value = Parrot_str_append(interp, value, CONST_STRING(interp, "Key type unknown"));
-                break;
+            }
+            break;
+          default:
+            value = Parrot_str_append(interp, value, CONST_STRING(interp, "Key type unknown"));
+            break;
         }
 
         GETATTR_Key_next_key(interp, key, next_key);
