@@ -1,6 +1,6 @@
 /*
 Copyright (C) 2001-2007, Parrot Foundation.
-$Id: longopt.c 37854 2009-04-01 20:00:45Z coke $
+$Id$
 
 =head1 NAME
 
@@ -19,7 +19,6 @@ This is used by C<parrot>.
 */
 
 #include "parrot/parrot.h"
-#include "parrot/longopt.h"
 
 /* HEADERIZER HFILE: include/parrot/longopt.h */
 
@@ -48,16 +47,16 @@ static int longopt_get_shortopt(PARROT_INTERP,
         __attribute__nonnull__(5)
         FUNC_MODIFIES(* info_buf);
 
-#define ASSERT_ARGS_longopt_get_longopt __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+#define ASSERT_ARGS_longopt_get_longopt __attribute__unused__ int _ASSERT_ARGS_CHECK = (\
        PARROT_ASSERT_ARG(interp) \
-    || PARROT_ASSERT_ARG(argv) \
-    || PARROT_ASSERT_ARG(options) \
-    || PARROT_ASSERT_ARG(info_buf)
-#define ASSERT_ARGS_longopt_get_shortopt __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+    , PARROT_ASSERT_ARG(argv) \
+    , PARROT_ASSERT_ARG(options) \
+    , PARROT_ASSERT_ARG(info_buf))
+#define ASSERT_ARGS_longopt_get_shortopt __attribute__unused__ int _ASSERT_ARGS_CHECK = (\
        PARROT_ASSERT_ARG(interp) \
-    || PARROT_ASSERT_ARG(argv) \
-    || PARROT_ASSERT_ARG(options) \
-    || PARROT_ASSERT_ARG(info_buf)
+    , PARROT_ASSERT_ARG(argv) \
+    , PARROT_ASSERT_ARG(options) \
+    , PARROT_ASSERT_ARG(info_buf))
 /* Don't modify between HEADERIZER BEGIN / HEADERIZER END.  Your changes will be lost. */
 /* HEADERIZER END: static */
 
