@@ -1,14 +1,16 @@
 /*
 Copyright (C) 2001-2009, Parrot Foundation.
-$Id: pmc.c 40100 2009-07-15 13:15:25Z bacek $
+$Id$
 
 =head1 NAME
 
-src/pmc.c - The base vtable calling functions
+src/pmc.c
 
 =head1 DESCRIPTION
 
-=head2 Functions
+The base vtable calling functions
+
+=head1 FUNCTIONS
 
 =over 4
 
@@ -19,6 +21,7 @@ src/pmc.c - The base vtable calling functions
 #include "parrot/parrot.h"
 #include "pmc.str"
 #include "pmc/pmc_class.h"
+#include "pmc/pmc_callcontext.h"
 
 /* HEADERIZER HFILE: include/parrot/pmc.h */
 
@@ -42,14 +45,6 @@ static PMC * get_new_pmc_header(PARROT_INTERP,
     UINTVAL flags)
         __attribute__nonnull__(1);
 
-static INTVAL pmc_reuse_check_pmc_ext(PARROT_INTERP,
-    ARGMOD(PMC * pmc),
-    INTVAL newflags,
-    INTVAL flags)
-        __attribute__nonnull__(1)
-        __attribute__nonnull__(2)
-        FUNC_MODIFIES(* pmc);
-
 PARROT_CANNOT_RETURN_NULL
 static PMC* pmc_reuse_no_init(PARROT_INTERP,
     ARGIN(PMC *pmc),
@@ -58,18 +53,15 @@ static PMC* pmc_reuse_no_init(PARROT_INTERP,
         __attribute__nonnull__(1)
         __attribute__nonnull__(2);
 
-#define ASSERT_ARGS_check_pmc_reuse_flags __attribute__unused__ int _ASSERT_ARGS_CHECK = \
-       PARROT_ASSERT_ARG(interp)
-#define ASSERT_ARGS_create_class_pmc __attribute__unused__ int _ASSERT_ARGS_CHECK = \
-       PARROT_ASSERT_ARG(interp)
-#define ASSERT_ARGS_get_new_pmc_header __attribute__unused__ int _ASSERT_ARGS_CHECK = \
-       PARROT_ASSERT_ARG(interp)
-#define ASSERT_ARGS_pmc_reuse_check_pmc_ext __attribute__unused__ int _ASSERT_ARGS_CHECK = \
+#define ASSERT_ARGS_check_pmc_reuse_flags __attribute__unused__ int _ASSERT_ARGS_CHECK = (\
+       PARROT_ASSERT_ARG(interp))
+#define ASSERT_ARGS_create_class_pmc __attribute__unused__ int _ASSERT_ARGS_CHECK = (\
+       PARROT_ASSERT_ARG(interp))
+#define ASSERT_ARGS_get_new_pmc_header __attribute__unused__ int _ASSERT_ARGS_CHECK = (\
+       PARROT_ASSERT_ARG(interp))
+#define ASSERT_ARGS_pmc_reuse_no_init __attribute__unused__ int _ASSERT_ARGS_CHECK = (\
        PARROT_ASSERT_ARG(interp) \
-    || PARROT_ASSERT_ARG(pmc)
-#define ASSERT_ARGS_pmc_reuse_no_init __attribute__unused__ int _ASSERT_ARGS_CHECK = \
-       PARROT_ASSERT_ARG(interp) \
-    || PARROT_ASSERT_ARG(pmc)
+    , PARROT_ASSERT_ARG(pmc))
 /* Don't modify between HEADERIZER BEGIN / HEADERIZER END.  Your changes will be lost. */
 /* HEADERIZER END: static */
 
@@ -102,6 +94,47 @@ PMC_is_null(SHIM_INTERP, ARGIN_NULLOK(const PMC *pmc))
 
 /*
 
+=item C<void Parrot_pmc_destroy(PARROT_INTERP, PMC *pmc)>
+
+Destroy a PMC. Call his destroy vtable function if needed, and deallocate
+his attributes if they are automatically allocated.
+
+For internal usage of the PMC handling functions and garbage collection
+subsystem.
+
+=cut
+
+*/
+
+PARROT_EXPORT
+void
+Parrot_pmc_destroy(PARROT_INTERP, ARGMOD(PMC *pmc))
+{
+    ASSERT_ARGS(Parrot_pmc_destroy)
+
+    if (PObj_custom_destroy_TEST(pmc))
+        VTABLE_destroy(interp, pmc);
+
+    PObj_gc_CLEAR(pmc);
+
+    if (PObj_is_PMC_shared_TEST(pmc) && PMC_sync(pmc))
+        Parrot_gc_free_pmc_sync(interp, pmc);
+
+    if (pmc->vtable->attr_size)
+        Parrot_gc_free_pmc_attributes(interp, pmc);
+    else
+        PMC_data(pmc) = NULL;
+
+#ifndef NDEBUG
+
+    pmc->vtable      = (VTABLE  *)0xdeadbeef;
+
+#endif
+
+}
+
+/*
+
 =item C<PMC * pmc_new(PARROT_INTERP, INTVAL base_type)>
 
 Creates a new PMC of type C<base_type> (which is an index into the list of PMC
@@ -229,18 +262,20 @@ pmc_reuse_no_init(PARROT_INTERP, ARGIN(PMC *pmc), INTVAL new_type,
     /* Singleton/const PMCs/types are not eligible */
     check_pmc_reuse_flags(interp, pmc->vtable->flags, new_vtable->flags);
 
-    /* Does the old PMC need any resources freed? */
-    if (PObj_active_destroy_TEST(pmc))
-        VTABLE_destroy(interp, pmc);
+    /* Free the old PMC resources. */
+    Parrot_pmc_destroy(interp, pmc);
 
-    new_flags = pmc_reuse_check_pmc_ext(interp, pmc, new_flags, new_vtable->flags);
-
-    /* we are a PMC + maybe is_PMC_EXT */
     PObj_flags_SETTO(pmc, PObj_is_PMC_FLAG | new_flags);
 
     /* Set the right vtable */
     pmc->vtable = new_vtable;
 
+    if (new_vtable->attr_size)
+        Parrot_gc_allocate_pmc_attributes(interp, pmc);
+
+    else
+        PMC_data(pmc) = NULL;
+
     return pmc;
 }
 
@@ -276,19 +311,18 @@ pmc_reuse_by_class(PARROT_INTERP, ARGMOD(PMC *pmc), ARGIN(PMC *class_),
     /* Singleton/const PMCs/types are not eligible */
     check_pmc_reuse_flags(interp, pmc->vtable->flags, new_vtable->flags);
 
-    /* Does the old PMC need any resources freed? */
-    if (PObj_active_destroy_TEST(pmc))
-        VTABLE_destroy(interp, pmc);
+    Parrot_pmc_destroy(interp, pmc);
 
-    new_flags = pmc_reuse_check_pmc_ext(interp, pmc,
-        new_flags, new_vtable->flags);
-
-    /* we are a PMC + maybe is_PMC_EXT */
     PObj_flags_SETTO(pmc, PObj_is_PMC_FLAG | new_flags);
 
     /* Set the right vtable */
     pmc->vtable = new_vtable;
 
+    if (new_vtable->attr_size)
+        Parrot_gc_allocate_pmc_attributes(interp, pmc);
+    else
+        PMC_data(pmc) = NULL;
+
     return pmc;
 }
 
@@ -341,45 +375,6 @@ check_pmc_reuse_flags(PARROT_INTERP, UINTVAL srcflags, UINTVAL destflags)
 
 /*
 
-=item C<static INTVAL pmc_reuse_check_pmc_ext(PARROT_INTERP, PMC * pmc, INTVAL
-newflags, INTVAL flags)>
-
-We are converting one PMC type into another, such as in C<pmc_reuse> or
-C<pmc_reuse_by_class>. Check to make sure that we have a pmc_ext if we need
-one, and that we don't have it if we don't need it. Returns the updated
-flags field with the C<PObj_is_PMC_EXT> flag set if necessary.
-
-=cut
-
-*/
-
-static INTVAL
-pmc_reuse_check_pmc_ext(PARROT_INTERP, ARGMOD(PMC * pmc),
-    INTVAL newflags, INTVAL flags)
-{
-    ASSERT_ARGS(pmc_reuse_check_pmc_ext)
-    /* Do we have an extension area? */
-    INTVAL const has_ext = (PObj_is_PMC_EXT_TEST(pmc) && pmc->pmc_ext);
-
-    /* Do we need one? */
-    if (flags & VTABLE_PMC_NEEDS_EXT) {
-        /* If we need an ext area, go allocate one */
-        Parrot_gc_add_pmc_ext(interp, pmc);
-        newflags |= PObj_is_PMC_EXT_FLAG;
-        PARROT_ASSERT((newflags & PObj_is_PMC_EXT_FLAG) != 0);
-    }
-    else {
-        Parrot_gc_free_pmc_ext(interp, pmc);
-        PMC_data(pmc) = NULL;
-        newflags &= ~PObj_is_PMC_EXT_FLAG;
-        PARROT_ASSERT((newflags & PObj_is_PMC_EXT_FLAG) == 0);
-        PARROT_ASSERT(pmc->pmc_ext == NULL);
-    }
-    return newflags;
-}
-
-/*
-
 =item C<static PMC * get_new_pmc_header(PARROT_INTERP, INTVAL base_type, UINTVAL
 flags)>
 
@@ -456,21 +451,14 @@ get_new_pmc_header(PARROT_INTERP, INTVAL base_type, UINTVAL flags)
         vtable = interp->vtables[base_type];
     }
 
-    if (vtable_flags & VTABLE_PMC_NEEDS_EXT) {
-        flags |= PObj_is_PMC_EXT_FLAG;
-        if (vtable_flags & VTABLE_IS_SHARED_FLAG)
-            flags |= PObj_is_PMC_shared_FLAG;
-    }
+    if (vtable_flags & VTABLE_IS_SHARED_FLAG)
+        flags |= PObj_is_PMC_shared_FLAG;
 
     pmc            = Parrot_gc_new_pmc_header(interp, flags);
     pmc->vtable    = vtable;
 
-#if GC_VERBOSE
-    if (Interp_flags_TEST(interp, PARROT_TRACE_FLAG)) {
-        /* XXX make a more verbose trace flag */
-        fprintf(stderr, "\t=> new %p type %d\n", pmc, (int)base_type);
-    }
-#endif
+    if (vtable->attr_size)
+        Parrot_gc_allocate_pmc_attributes(interp, pmc);
 
     return pmc;
 }
@@ -810,11 +798,10 @@ create_class_pmc(PARROT_INTERP, INTVAL type)
      * original because we have a singleton. Just set the singleton to
      * be our class object, but don't mess with its vtable.  */
     if ((interp->vtables[type]->flags & VTABLE_PMC_IS_SINGLETON)
-    &&  (_class == _class->vtable->pmc_class)) {
+    &&  (_class == _class->vtable->pmc_class))
         interp->vtables[type]->pmc_class = _class;
-    }
     else {
-        Parrot_gc_free_pmc_ext(interp, _class);
+        Parrot_gc_free_pmc_sync(interp, _class);
         gc_flag_CLEAR(is_special_PMC, _class);
         PObj_is_PMC_shared_CLEAR(_class);
         interp->vtables[type]->pmc_class = _class;
@@ -877,7 +864,7 @@ Parrot_create_mro(PARROT_INTERP, INTVAL type)
 
             /* anchor at parent, aka current_namespace, that is 'parrot' */
             VTABLE_set_pmc_keyed_str(interp,
-                    CONTEXT(interp)->current_namespace, class_name, ns);
+                    Parrot_pcc_get_namespace(interp, CURRENT_CONTEXT(interp)), class_name, ns);
         }
 
         _class = vtable->pmc_class;
