@@ -1,7 +1,7 @@
 /* unicode.h
  *  Copyright (C) 2005-2007, Parrot Foundation.
  *  SVN Info
- *     $Id: unicode.h 37201 2009-03-08 12:07:48Z fperrad $
+ *     $Id$
  *  Overview:
  *     This is the header for the unicode charset functions
  *  Data Structure and Algorithms:
@@ -25,8 +25,8 @@ PARROT_CANNOT_RETURN_NULL
 const CHARSET * Parrot_charset_unicode_init(PARROT_INTERP)
         __attribute__nonnull__(1);
 
-#define ASSERT_ARGS_Parrot_charset_unicode_init __attribute__unused__ int _ASSERT_ARGS_CHECK = \
-       PARROT_ASSERT_ARG(interp)
+#define ASSERT_ARGS_Parrot_charset_unicode_init __attribute__unused__ int _ASSERT_ARGS_CHECK = (\
+       PARROT_ASSERT_ARG(interp))
 /* Don't modify between HEADERIZER BEGIN / HEADERIZER END.  Your changes will be lost. */
 /* HEADERIZER END: src/string/charset/unicode.c */
 
